@@ -58,10 +58,10 @@ class Assets(WMLResource):
         Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
 
         if not self._ICP and not self._client.WSD:
-            response = requests.get(self._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
+            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
                                     headers=self._client._get_headers())
         else:
-            response = requests.get(self._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
+            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
                                       headers=self._client._get_headers(), verify=False)
         if response.status_code == 200:
             return self._get_required_element_from_response(self._handle_response(200, u'get asset details', response))
@@ -217,14 +217,14 @@ class Assets(WMLResource):
 
             if not self._ICP:
                 creation_response = requests.post(
-                        self._href_definitions.get_data_assets_href(),
+                        self._client.service_instance._href_definitions.get_data_assets_href(),
                         headers=self._client._get_headers(),
                         params = self._client._params(),
                         json=asset_meta
                 )
             else:
                 creation_response = requests.post(
-                    self._href_definitions.get_data_assets_href(),
+                    self._client.service_instance._href_definitions.get_data_assets_href(),
                     headers=self._client._get_headers(),
                     json=asset_meta,
                     params=self._client._params(),
@@ -249,14 +249,14 @@ class Assets(WMLResource):
 
                 if not self._ICP:
                     attachment_response = requests.post(
-                        self._href_definitions.get_attachments_href(asset_id),
+                        self._client.service_instance._href_definitions.get_attachments_href(asset_id),
                         headers=self._client._get_headers(),
                         params=self._client._params(),
                         json=attachment_meta
                     )
                 else:
                     attachment_response = requests.post(
-                        self._wml_credentials['url']+"/v2/assets/"+asset_id+"/attachments",
+                        self._client.service_instance._href_definitions.get_attachments_href(asset_id),
                         headers=self._client._get_headers(),
                         json=attachment_meta,
                         params=self._client._params(),
@@ -285,15 +285,15 @@ class Assets(WMLResource):
                             # Step4: Complete attachment
                             if not self._ICP:
                                 complete_response = requests.post(
-                                    # self._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
-                                    self._href_definitions.get_attachment_complete_href(asset_id, attachment_id),
+                                    # self._client.service_instance._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
+                                    self._client.service_instance._href_definitions.get_attachment_complete_href(asset_id, attachment_id),
                                     headers=self._client._get_headers(),
                                     params = self._client._params()
 
                                 )
                             else:
                                 complete_response = requests.post(
-                                    self._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
+                                    self._client.service_instance._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
                                     headers=self._client._get_headers(),
                                     params=self._client._params(),
                                     verify=False
@@ -338,7 +338,7 @@ class Assets(WMLResource):
         """
 
         Assets._validate_type(limit, u'limit', int, False)
-        href = self._href_definitions.get_search_asset_href()
+        href = self._client.service_instance._href_definitions.get_search_asset_href()
 
         data = {
                 "query": "*:*"
@@ -389,18 +389,18 @@ class Assets(WMLResource):
 
         import urllib
         if not self._ICP and not self._client.WSD:
-            asset_response = requests.get(self._href_definitions.get_data_asset_href(asset_uid),
+            asset_response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid),
                                           params=self._client._params(),
                                           headers=self._client._get_headers())
         else:
-            asset_response = requests.get(self._href_definitions.get_data_asset_href(asset_uid),
+            asset_response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid),
                                           params=self._client._params(),
                                           headers=self._client._get_headers(), verify=False)
         asset_details = self._handle_response(200, u'get assets', asset_response)
 
         if self._WSD:
             attachment_url = asset_details['attachments'][0]['object_key']
-            artifact_content_url = self._href_definitions.get_wsd_model_attachment_href() + \
+            artifact_content_url = self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + \
                                    urllib.parse.quote('data_asset/' + attachment_url, safe='')
 
             r = requests.get(artifact_content_url, params=self._client._params(), headers=self._client._get_headers(),
@@ -419,10 +419,10 @@ class Assets(WMLResource):
         else:
             attachment_id = asset_details["attachments"][0]["id"]
             if not self._ICP and not self._client.WSD:
-                response = requests.get(self._href_definitions.get_attachment_href(asset_uid,attachment_id), params=self._client._params(),
+                response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id), params=self._client._params(),
                                         headers=self._client._get_headers())
             else:
-                response = requests.get(self._href_definitions.get_attachment_href(asset_uid,attachment_id), params=self._client._params(),
+                response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id), params=self._client._params(),
                                           headers=self._client._get_headers(), verify=False)
             if response.status_code == 200:
                 if 'connection_id' in asset_details["attachments"][0] and \
@@ -580,10 +580,10 @@ class Assets(WMLResource):
         Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
 
         if not self._ICP and not self._client.WSD:
-            response = requests.delete(self._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                     headers=self._client._get_headers())
         else:
-            response = requests.delete(self._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                       headers=self._client._get_headers(), verify=False)
         if response.status_code == 200:
             return self._get_required_element_from_response(response.json())
@@ -595,10 +595,10 @@ class Assets(WMLResource):
         Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
 
         if not self._ICP and not self._client.WSD:
-            response = requests.delete(self._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                        headers=self._client._get_headers())
         else:
-            response = requests.delete(self._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                        headers=self._client._get_headers(), verify=False)
 
 
@@ -641,10 +641,10 @@ class Assets(WMLResource):
     #     Assets._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
     #
     #     if not self._ICP:
-    #         response = requests.get(self._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
+    #         response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
     #                                 headers=self._client._get_headers())
     #     else:
-    #         response = requests.get(self._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
+    #         response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid), params=self._client._params(),
     #                                 headers=self._client._get_headers(), verify=False)
     #     if response.status_code == 200:
     #         return response.json()["href"]
@@ -669,7 +669,7 @@ class Assets(WMLResource):
             elif self._client.default_project_id is not None:
                 if self._client.WSD:
 
-                    href = "/v2/assets/" + response_data['metadata']['asset_id'] + "?" + "project_id=" + response_data['metadata']['project_id']
+                    href = self._client.service_instance._href_definitions.get_base_asset_href(response_data['metadata']['asset_id']) + "?" + "project_id=" + response_data['metadata']['project_id']
 
                     new_el = {'metadata': {'project_id': response_data['metadata']['project_id'],
                                            'guid': response_data['metadata']['asset_id'],
