@@ -74,6 +74,7 @@ class APIClient:
         self.ICP = None
         self.default_space_id = None
         self.default_project_id = None
+        self.project_type = None
         self.CLOUD_PLATFORM_SPACES = False
         self.PLATFORM_URL = None
         self.CAMS_URL = None
@@ -81,6 +82,7 @@ class APIClient:
         self.version_param = '2020-08-01'
         self.ICP_PLATFORM_SPACES = False # This will be applicable for 3.5 and later and specific to convergence functionalities
         self.ICP_35 = False # Use it for any 3.5 specific functionalities
+        self.ICP_40 = False # Use it for any 4.0 specific functionalities
         self.CLOUD_BETA_FLOW = False
         # self.version_param = '2020-06-12'
 
@@ -107,7 +109,7 @@ class APIClient:
         self.wml_token = None
         self.__wml_local_supported_version_list = ['1.0', '1.1',
                                                    '2.0', '2.0.1', '2.0.2', '2.5.0',
-                                                   '3.0.0', '3.0.1', '3.5']
+                                                   '3.0.0', '3.0.1', '3.5', '4.0']
         self.__wsd_supported_version_list = ['1.0', '1.1', '2.0']
         self.__predefined_instance_type_list = ['icp', 'openshift', 'wml_local', 'wsd_local']
         os.environ['WSD_PLATFORM'] = 'False'
@@ -141,6 +143,7 @@ class APIClient:
                     u'version'].lower() or
                         '3.0.0' == wml_credentials[u'version'].lower() or '3.0.1' == wml_credentials[
                             u'version'].lower() or '3.5' == wml_credentials[u'version'].lower() or
+                        '4.0' == wml_credentials[u'version'].lower() or
                         '1.1' == wml_credentials[u'version'].lower() or '2.0' == wml_credentials[u'version'].lower()):
                     self.CAMS = True
                     os.environ["DEPLOYMENT_PRIVATE"] = "icp4d"
@@ -161,6 +164,10 @@ class APIClient:
                         self.ICP_PLATFORM_SPACES = True
                         self.ICP_35 = True
 
+                    if '4.0' == wml_credentials[u'version'].lower():
+                        self.ICP_PLATFORM_SPACES = True
+                        self.ICP_40 = True
+
                 else:
                     if 'version' in wml_credentials.keys() and \
                             wml_credentials[u'version'].lower() not in self.__wml_local_supported_version_list:
@@ -299,7 +306,7 @@ class APIClient:
             import sys
             if (3 == sys.version_info.major) and (6 == sys.version_info.minor):
                 if self.CLOUD_PLATFORM_SPACES:
-                    print("DEPRECATED!! Python 3.6 framework is deprecated and will be removed on Jan 20th, 2021. "
+                    print("DEPRECATED!! Python 3.6 framework is deprecated and will be removed on Apr 8th, 2021. "
                           "It will be read-only mode starting Nov 20th, 2020. i.e you won't be able to create new assets using this client. "
                           "Use Python 3.7 instead. For details, see https://dataplatform.cloud.ibm.com/docs/content/wsj/analyze-data/pm_service_supported_frameworks.html")
                 elif self.ICP_PLATFORM_SPACES:
@@ -410,6 +417,13 @@ class APIClient:
             else:
                 raise WMLClientError(
                     "It is mandatory to set the project id. Use client.set.default_project(<PROJECT_UID>) to proceed.")
+
+        if self.project_type == 'local_git_storage':
+            params.update({'userfs': 'true'})
+
+        if self.project_type != 'local_git_storage' and 'userfs' in params:
+            del params['userfs']
+
         return params
 
     def _get_headers(self, content_type='application/json', no_content_type=False, wsdconnection_api_req=False, zen=False):
