@@ -119,6 +119,10 @@ class BaseDeployment(ABC):
                 self._target_workspace = None
         # --- end note
 
+        if self._source_workspace is None and self._target_workspace is None:
+            raise TypeError(f"{self.__class__.__name__} is missing one of the parameters: "
+                            f"['source_wml_credentials', 'target_wml_credentials']")
+
         self.name = None
         self.id = None
         if deployment_type == 'online':
