@@ -461,8 +461,13 @@ class Batch(BaseDeployment):
                 conn._wml_client = self._target_workspace.wml_client
                 if len(scoring_params['input_data_references']) > 1 and not self._target_workspace.wml_client.ICP:
                     conn._obm = True
+                    # TODO: remove S3 implementation
                     if conn.type == DataConnectionTypes.S3:
                         conn._obm_cos_path = scoring_params['output_data_reference']['location']['path']
+
+                    elif conn.type == DataConnectionTypes.CA and conn._check_if_connection_asset_is_s3():
+                        conn._obm_cos_path = scoring_params['output_data_reference']['location']['path']
+
                 return conn.read() # if in future output may be excel file or with custom separator, here it should be recognized
         else:
             raise MissingScoringResults(scoring_job_id, reason="Scoring is not completed.")
