@@ -191,7 +191,7 @@ class Deployments(WMLResource):
                             raise WMLClientError(
                                 "It is mandatory is set the space. Use client.set.default_space(<SPACE_GUID>) to set the space.")
 
-            url = self._href_definitions.get_deployments_href()
+            url = self._client.service_instance._href_definitions.get_deployments_href()
             if not self._ICP:
                 if self._client.CLOUD_PLATFORM_SPACES:
                     response = requests.post(
@@ -416,12 +416,12 @@ class Deployments(WMLResource):
         if deployment_uid is not None and not is_uid(deployment_uid):
             raise WMLClientError(u'\'deployment_uid\' is not an uid: \'{}\''.format(deployment_uid))
 
-        url = self._href_definitions.get_deployments_href()
+        url = self._client.service_instance._href_definitions.get_deployments_href()
         ## TODO:  Adding a work around till v4/deployment accepts space_id query parameter for GET
         if self._ICP and not self._client.ICP_PLATFORM_SPACES:
             if deployment_uid is not None:
                 url = url + '/' + deployment_uid
-                if self._client.ICP_35:
+                if self._client.ICP_35 or self._client.ICP_40:
                     response = requests.get(
                         url,
                         params = self._client._params(),
@@ -519,7 +519,7 @@ class Deployments(WMLResource):
         if deployment_uid is not None and not is_uid(deployment_uid):
             raise WMLClientError(u'\'deployment_uid\' is not an uid: \'{}\''.format(deployment_uid))
 
-        deployment_url = self._href_definitions.get_deployment_href(deployment_uid)
+        deployment_url = self._client.service_instance._href_definitions.get_deployment_href(deployment_uid)
 
         if not self._ICP:
             response_delete = requests.delete(
@@ -748,7 +748,7 @@ class Deployments(WMLResource):
         params = self._client._params()
         details = self.get_details(virtual_deployment_uid)
         download_url = self.get_download_url(details)
-        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35:
+        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40:
             download_url = download_url + "&version=2020-08-01"
             params = None
         if not self._ICP:
@@ -1037,7 +1037,7 @@ class Deployments(WMLResource):
                 else:
                     ele['value']='false'
 
-        url = self._href_definitions.get_deployment_href(deployment_uid)
+        url = self._client.service_instance._href_definitions.get_deployment_href(deployment_uid)
 
         if not self._ICP:
             response = requests.patch(url, json=patch_payload, params=self._client._params(),headers=self._client._get_headers())
@@ -1098,8 +1098,7 @@ class Deployments(WMLResource):
     ## Below functions are for async scoring. They are just dummy functions.
     def _score_async(self,deployment_uid, scoring_payload,
                      transaction_id=None,
-                     retention=None,
-                     platform_job_immediate=None):
+                     retention=None):
 
         Deployments._validate_type(deployment_uid, u'deployment_id', STR_TYPE, True)
         Deployments._validate_type(scoring_payload, u'scoring_payload', dict, True)
@@ -1108,7 +1107,7 @@ class Deployments(WMLResource):
         if transaction_id is not None:
             headers.update({'x-global-transaction-id': transaction_id})
         # making change - connection keep alive
-        scoring_url = self._href_definitions.get_async_deployment_job_href()
+        scoring_url = self._client.service_instance._href_definitions.get_async_deployment_job_href()
         if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
             params = self._client._params()
         else:
@@ -1118,10 +1117,6 @@ class Deployments(WMLResource):
             if not isinstance(retention, int) or retention < -1:
                 raise TypeError("`retention` takes integer values greater or equal than -1.")
             params.update({'retention': retention})
-        if platform_job_immediate is not None:
-            if not isinstance(platform_job_immediate, bool):
-                raise TypeError("`platform_job_immediate` only takes boolean values.")
-            params.update({'platform_job_immediate': platform_job_immediate})
 
         if not self._ICP:
             response_scoring = self.session.post(
@@ -1139,7 +1134,7 @@ class Deployments(WMLResource):
 
         return self._handle_response(202, u'scoring asynchronously', response_scoring)
 
-    def create_job(self, deployment_id, meta_props, retention=None, platform_job_immediate=None):
+    def create_job(self, deployment_id, meta_props, retention=None):
         """
             Create an asynchronous deployment job.
 
@@ -1159,9 +1154,6 @@ class Deployments(WMLResource):
                                   Supported only on Cloud.\n
                    **type**:: int\n
 
-                #. **platform_job_immediate**: Set the platform job task to syns or async mode (optinal).\n
-                   **type**: bool\n
-
             **Output**
 
             .. important::
@@ -1230,7 +1222,7 @@ class Deployments(WMLResource):
                     # Check feature types, currently supporting pandas df, numpy.ndarray, python lists and Dmatrix
                     if (isinstance(scoring_values, pd.DataFrame)):
                         fields_names = scoring_values.columns.values.tolist()
-                        values = scoring_values.values.tolist()
+                        values = scoring_values.where(pd.notnull(scoring_values), None).values.tolist() #replace nan with None
 
                         each_score_request["values"] = values
                         if fields_names is not None:
@@ -1241,7 +1233,7 @@ class Deployments(WMLResource):
 
                     elif (isinstance(scoring_values, np.ndarray)):
 
-                        values = scoring_values.tolist()
+                        values = np.where(pd.notnull(scoring_values), scoring_values, None).tolist() #replace nan with None
                         each_score_request["values"] = values
 
 
@@ -1312,8 +1304,7 @@ class Deployments(WMLResource):
 
         return self._score_async(deployment_id, payload,
                                  transaction_id=None,
-                                 retention=retention,
-                                 platform_job_immediate=platform_job_immediate)
+                                 retention=retention)
 
     def get_job_details(self, job_uid=None, limit=None):
         """
@@ -1347,7 +1338,7 @@ class Deployments(WMLResource):
         """
         if job_uid is not None:
             Deployments._validate_type(job_uid, u'job_uid', STR_TYPE, True)
-        url = self._href_definitions.get_async_deployment_job_href()
+        url = self._client.service_instance._href_definitions.get_async_deployment_job_href()
 
         if self._ICP:
             if job_uid is not None:
@@ -1491,7 +1482,7 @@ class Deployments(WMLResource):
         if job_uid is not None and not is_uid(job_uid):
             raise WMLClientError(u'\'job_uid\' is not an uid: \'{}\''.format(job_uid))
 
-        url = self._href_definitions.get_async_deployment_jobs_href(job_uid)
+        url = self._client.service_instance._href_definitions.get_async_deployment_jobs_href(job_uid)
 
         if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_PLATFORM_SPACES:
             params = self._client._params()
@@ -1542,7 +1533,7 @@ class Deployments(WMLResource):
     #     Deployments._validate_type(meta_props, u'metaprops', dict, True)
     #
     #
-    #     url = self._href_definitions.get_envs_href()
+    #     url = self._client.service_instance._href_definitions.get_envs_href()
     #     metadata = self.EnvironmentMetanames._generate_resource_metadata(meta_props)
     #
     #     if not self._ICP:
@@ -1588,7 +1579,7 @@ class Deployments(WMLResource):
     #         raise WMLClientError(u'\'env_id\' is not an uid: \'{}\''.format(env_id))
     #
     #
-    #     url = self._href_definitions.get_env_href(env_id)
+    #     url = self._client.service_instance._href_definitions.get_env_href(env_id)
     #
     #     if not self._ICP:
     #         response_delete = requests.delete(
@@ -1681,7 +1672,7 @@ class Deployments(WMLResource):
     #     """
     #     #Deployments._validate_type(job_uid, u'deployment_uid', STR_TYPE, True)
     #     #Deployments._validate_type(job_uid, u'job_uid', STR_TYPE, True)
-    #     url = self._href_definitions.get_envs_href()
+    #     url = self._client.service_instance._href_definitions.get_envs_href()
     #     return self._get_artifact_details(url, env_id, limit, 'get environments details')
     #
     # def list_environments(self,limit=None):
