@@ -163,8 +163,8 @@ class AutoAI(BaseExperiment):
                   positive_label: str = None,
                   data_join_only: bool = False,
                   drop_duplicates: bool = True,
-                  # text_processing: bool = True,
-                  # word2vec_feature_number: int = None,
+                  text_processing: bool = None,
+                  word2vec_feature_number: int = None,
                   **kwargs) -> Union['RemoteAutoPipelines', 'LocalAutoPipelines']:
         """
         Initialize an AutoAi optimizer.
@@ -264,6 +264,13 @@ class AutoAI(BaseExperiment):
         drop_duplicates: bool, optional
             If True duplicated rows in data will be removed before further processing. Default is True.
 
+        text_processing: bool, optional
+            If True text processing will be enabled. Default is True. Applicable only on Cloud.
+
+        word2vec_feature_number: int, optional
+            Number of features which will be generated from text column. Will be applied only if `text_processing`
+            is True. If `None` the default value will be taken.
+
         Returns
         -------
         RemoteAutoPipelines or LocalAutoPipelines, depends on how you initialize the AutoAI object.
@@ -295,32 +302,6 @@ class AutoAI(BaseExperiment):
         >>>        desc="Some description.",
         >>>    )
         """
-        # To be removed when Text Transformer enabled officially:
-
-            # text_processing: bool, optional
-            #     If True text processing will be enabled. Default is True.
-            #
-            # word2vec_feature_number: int, optional
-            #     Number of features which will be generated from text column. Will be applied only if `text_processing`
-            #     is True. If `None` the default value will be taken.
-
-        if 'tt_enabled' in self._workspace.wml_client.wml_credentials \
-                or self._workspace.wml_client.wml_credentials.get('tt_enabled'):
-            text_processing = kwargs.get('text_processing')
-            word2vec_feature_number = kwargs.get('word2vec_feature_number')
-        else:
-            text_processing = None
-            word2vec_feature_number = None
-        try:
-            del kwargs['text_processing']
-        except:
-            pass
-        try:
-            del kwargs['word2vec_feature_number']
-        except:
-            pass
-
-        # - end of Text Transformer section
 
         if prediction_type == PredictionType.FORECASTING and self._workspace.wml_client.ICP and \
                 (self._workspace.wml_client.wml_credentials['version'].startswith('2.5') or \
