@@ -12,7 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from typing import TYPE_CHECKING, List, Dict
+from typing import TYPE_CHECKING, List, Dict, Tuple
 
 from pandas import DataFrame, MultiIndex
 import json
@@ -116,20 +116,18 @@ class WMLEngine(BaseEngine):
             }
         }
 
-        # To be modified when text transformer will be supported.
-        # Copy setting these text transformer params setup without if in dictionary above in _wml_pipeline_metadata
-        #
+        # Text transformer params
+        if not self._wml_client.ICP_30 and not self._wml_client.ICP_35:
+            if self._auto_pipelines_parameters.get('text_processing') is not None:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'text_processing_flag'] = self._auto_pipelines_parameters.get('text_processing')
 
-        if self._auto_pipelines_parameters.get('text_processing') is not None:
-            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
-                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
-                'text_processing_flag'] = self._auto_pipelines_parameters.get('text_processing')
-
-        if self._auto_pipelines_parameters.get('word2vec_feature_number') is not None:
-            self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
-                'pipelines'][0]['nodes'][0]['parameters']['optimization'][
-                'text_processing_options'] = {'word2vec':
-                                            {'output_dim': self._auto_pipelines_parameters.get('word2vec_feature_number')}}
+            if self._auto_pipelines_parameters.get('word2vec_feature_number') is not None:
+                self._wml_pipeline_metadata[self._wml_client.pipelines.ConfigurationMetaNames.DOCUMENT][
+                    'pipelines'][0]['nodes'][0]['parameters']['optimization'][
+                    'text_processing_options'] = {'word2vec':
+                                                {'output_dim': self._auto_pipelines_parameters.get('word2vec_feature_number')}}
 
         # end of section
 
@@ -331,7 +329,7 @@ class WMLEngine(BaseEngine):
         """
         self._wml_training_metadata = {
             self._wml_client.training.ConfigurationMetaNames.TAGS:
-                [{'value': 'autoai'}],
+                ['autoai'],
 
             self._wml_client.training.ConfigurationMetaNames.TRAINING_DATA_REFERENCES:
                 [connection._to_dict() for connection in training_data_reference],
@@ -411,7 +409,7 @@ class WMLEngine(BaseEngine):
         run_params = self._wml_client.training.run(meta_props=self._wml_training_metadata,
                                                    asynchronous=True)
 
-        self._current_run_id = run_params['metadata']['guid']
+        self._current_run_id = run_params['metadata'].get('id', run_params['metadata'].get('guid'))
 
         if background_mode:
             return self._wml_client.training.get_details(training_uid=self._current_run_id)
@@ -765,7 +763,8 @@ class WMLEngine(BaseEngine):
             raise ValueError(f"Wrong option for \"one_vs_all\": {option}. "
                              f"Available options: [confusion_matrix, roc_curve]")
 
-    def get_pipeline(self, pipeline_name: str, local_path: str = '.', persist: 'bool' = False) -> 'Pipeline':
+    def get_pipeline(self, pipeline_name: str, local_path: str = '.',
+                     persist: 'bool' = False) -> Tuple['Pipeline', bool]:
         """
         Download specified pipeline from WML.
 
@@ -793,11 +792,18 @@ class WMLEngine(BaseEngine):
 
         run_params = self._wml_client.training.get_details(training_uid=self._current_run_id)
 
+        # note: recreation of s3 creds from connection asset
+        results_reference = DataConnection._from_dict(run_params['entity']['results_reference'])
+        results_reference._wml_client = self._wml_client
+        results_reference._check_if_connection_asset_is_s3()
+        run_params['entity']['results_reference'] = results_reference._to_dict()
+        # --- end note
+
         if 'timeseries' in run_params['entity']['status']['metrics'][0]['context']:
             raise ForecastingUnsupportedOperation()
 
         try:
-            pipelines: Dict[str, 'Pipeline'] = fetch_pipelines(
+            pipelines, check_lale = fetch_pipelines(
                 run_params=run_params,
                 path=local_path,
                 pipeline_name=pipeline_name,
@@ -814,9 +820,9 @@ class WMLEngine(BaseEngine):
                 pipeline_name,
                 reason=f'Fit finished but there was some error during loading a pipeline from WML. Error: {e}')
 
-        return pipelines.get(pipeline_name)
+        return pipelines.get(pipeline_name), check_lale
 
-    def get_best_pipeline(self, local_path: str = '.', persist: 'bool' = False) -> 'Pipeline':
+    def get_best_pipeline(self, local_path: str = '.', persist: 'bool' = False) -> Tuple['Pipeline', bool]:
         """
         Download best pipeline from WML.
 
