@@ -27,11 +27,12 @@ from ibm_watson_machine_learning.utils.autoai.enums import (
 from ibm_watson_machine_learning.utils.autoai.errors import (
     FitNotCompleted, MissingDataPreprocessingStep, WrongDataJoinGraphNodeName, DataSourceSizeNotSupported,
     TrainingDataSourceIsNotFile, NoneDataConnection, PipelineNotLoaded, OBMForNFSIsNotSupported,
-    ForecastingUnsupportedOperation, LibraryNotCompatible)
+    ForecastingUnsupportedOperation, LibraryNotCompatible, InvalidDataAsset)
 from ibm_watson_machine_learning.utils.autoai.utils import try_import_lale
 from ibm_watson_machine_learning.utils.autoai.wsd_ui import (
     save_computed_pipelines_for_ui, save_experiment_for_ui, save_metadata_for_ui)
-from ibm_watson_machine_learning.utils.autoai.connection import validate_source_data_connections, validate_results_data_connection
+from ibm_watson_machine_learning.utils.autoai.connection import validate_source_data_connections, \
+    validate_results_data_connection
 from .base_auto_pipelines import BaseAutoPipelines
 
 if TYPE_CHECKING:
@@ -292,10 +293,13 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             raise NoneDataConnection('training_data_reference')
 
         for conn in training_data_reference:
+            conn._wml_client = self._workspace.wml_client
+            # TODO: remove S3 implementation
             if conn.type == DataConnectionTypes.S3:
                 conn._validate_cos_resource()
 
-        training_data_reference = [new_conn for conn in training_data_reference for new_conn in conn._subdivide_connection()]
+        training_data_reference = [new_conn for conn in training_data_reference for new_conn in
+                                   conn._subdivide_connection()]
 
         # note: check if DataJoinGraph node names are correct and equivalent
         # to training DataConnections IDs/data_join_node_names
@@ -327,7 +331,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         else:
             raise TypeError("train_data should be of type pandas.DataFrame")
 
-        self._validate_training_data_size(training_data_reference)
+        # self._validate_training_data_size(training_data_reference)
 
         training_data_reference = validate_source_data_connections(training_data_reference, workspace=self._workspace,
                                                                    deployment=False)
@@ -341,6 +345,23 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                                         path='.')
                 )
 
+            elif isinstance(training_data_reference[0].location, AssetLocation) and not self._workspace.wml_client.ICP:
+                try:
+                    connection_id = training_data_reference[0].location._get_connection_id(self._workspace.wml_client)
+
+                except InvalidDataAsset:
+                    raise InvalidDataAsset(
+                        reason="Please specify Data Asset pointing to connection e.g. COS as an output.")
+
+                data_asset_details = self._workspace.wml_client.data_assets.store(
+                    {'connection_id': connection_id,
+                     "name": 'Default autoai output',
+                     'data_content_name': 'default_autoai_out'
+                     })
+
+                training_results_reference = DataConnection(
+                    data_asset_id=data_asset_details['metadata']['guid'])
+
             else:
                 location = FSLocation()
                 if self._workspace.WMLS:
@@ -359,10 +380,17 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                     location=location
                 )
         # -- end note
+        if isinstance(training_results_reference.location, AssetLocation):
+            try:
+                training_results_reference.location._get_connection_id(self._workspace.wml_client)
+
+            except InvalidDataAsset:
+                raise InvalidDataAsset(reason="Please specify Data Asset pointing to connection e.g. COS as an output.")
+
         # note: results can be stored only on FS or COS
-        if not isinstance(training_results_reference.location, (S3Location, FSLocation)):
+        if not isinstance(training_results_reference.location, (S3Location, FSLocation, AssetLocation)):
             raise TypeError('Unsupported results location type. Results referance can be stored'
-                            ' only on S3Location or FSLocation.')
+                            ' only on S3Location or FSLocation or AssetLocation.')
         # -- end
 
         # note: only if we are going with OBM + KB scenario, add ID to results DataConnection
@@ -374,7 +402,9 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                                       training_results_reference=training_results_reference,
                                       background_mode=background_mode)
 
-        if isinstance(training_data_reference[0].location, WSDAssetLocation) or (isinstance(training_data_reference[0].location, AssetLocation) and training_data_reference[0].location._wsd):
+        if isinstance(training_data_reference[0].location, WSDAssetLocation) or (
+                isinstance(training_data_reference[0].location, AssetLocation) and training_data_reference[
+            0].location._wsd):
             try:
                 wml_pipeline_details = self._workspace.wml_client.pipelines.get_details(
                     run_params['entity']['pipeline']['id'])
@@ -535,17 +565,12 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             Selected pipeline stored under: "absolute_local_path_to_model/model.pickle"
 
         """
-        # note: lale should be installed first as lightgbm is sometimes needed during sklearn pipeline load
-        if astype == PipelineTypes.LALE:
-            try_import_lale()
-        # --- end note
-
         try:
             if pipeline_name is None:
-                pipeline_model = self._engine.get_best_pipeline(persist=persist)
+                pipeline_model, check_lale = self._engine.get_best_pipeline(persist=persist)
 
             else:
-                pipeline_model = self._engine.get_pipeline(pipeline_name=pipeline_name, persist=persist)
+                pipeline_model, check_lale = self._engine.get_pipeline(pipeline_name=pipeline_name, persist=persist)
 
         except ForecastingUnsupportedOperation as e:
             raise e
@@ -562,13 +587,15 @@ class RemoteAutoPipelines(BaseAutoPipelines):
             return pipeline_model
 
         elif astype == PipelineTypes.LALE:
+            if check_lale:
+                try_import_lale()
             from lale.helpers import import_from_sklearn_pipeline
             # note: join preprocessing step to final pipeline (enables wider visualization and pretty print)
             try:
                 import numpy as np
                 preprocessing_object = self.get_preprocessing_pipeline()
                 preprocessing_pipeline = preprocessing_object.lale_pipeline
-                
+
                 # note: fake fit for preprocessing pipeline to be able to predict
                 preprocessing_pipeline = preprocessing_pipeline.fit(np.array([[1, 2, 3], [2, 3, 4]]), np.array([1, 2]))
                 return preprocessing_pipeline >> import_from_sklearn_pipeline(pipeline_model)
@@ -604,7 +631,7 @@ class RemoteAutoPipelines(BaseAutoPipelines):
         if self.best_pipeline is None:
             # note: automatically download the best computed pipeline
             if self.get_run_status() == RunStateTypes.COMPLETED:
-                self.best_pipeline = self._engine.get_best_pipeline()
+                self.best_pipeline, _ = self._engine.get_best_pipeline()
             else:
                 raise FitNotCompleted(self._engine._current_run_id,
                                       reason="Please check the run status with run_status() method.")
@@ -663,8 +690,8 @@ class RemoteAutoPipelines(BaseAutoPipelines):
                 elif t_shirt_size in (TShirtSize.ML, TShirtSize.L) and size > 1024 * 1024 * 1024:
                     raise DataSourceSizeNotSupported()
             else:
-                pass # note: data source size checking for other environment is not implemented
-              
+                pass  # note: data source size checking for other environment is not implemented
+
     def get_preprocessed_data_connection(self) -> 'DataConnection':
         """
         Create DataConnection object for further user usage (with OBM output)
