@@ -25,7 +25,7 @@ from ibm_watson_machine_learning.experiment.autoai.engines import WMLEngine
 from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoPipelines
 from ibm_watson_machine_learning.preprocessing import DataJoinGraph
 from ibm_watson_machine_learning.utils.autoai.utils import NextRunDetailsGenerator, get_node_and_runtime_index
-from ibm_watson_machine_learning.helpers import DataConnection, S3Location
+from ibm_watson_machine_learning.helpers import DataConnection, S3Location, AssetLocation
 from .base_auto_pipelines_runs import BaseAutoPipelinesRuns
 from ibm_watson_machine_learning.wml_client_error import ApiRequestFailure
 
@@ -100,7 +100,7 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
             wml_pipelines_types.append(wml_pipeline_type)
 
         if self.auto_pipeline_optimizer_name is not None:
-            values = [[timestamp, run['metadata']['guid'], run['entity']['status']['state'], wml_pipeline_name] for
+            values = [[timestamp, run['metadata'].get('id', run['metadata'].get('guid')), run['entity']['status']['state'], wml_pipeline_name] for
                       timestamp, run, wml_pipeline_name, wml_pipeline_type in zip(runs_timestamps,
                                                                                   data,
                                                                                   wml_pipelines_names,
@@ -108,7 +108,7 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
                       if wml_pipeline_name == self.auto_pipeline_optimizer_name and wml_pipeline_type == 'autoai']
 
         else:
-            values = [[timestamp, run['metadata']['guid'], run['entity']['status']['state'], wml_pipeline_name] for
+            values = [[timestamp, run['metadata'].get('id', run['metadata'].get('guid')), run['entity']['status']['state'], wml_pipeline_name] for
                       timestamp, run, wml_pipeline_name, wml_pipeline_type in zip(runs_timestamps,
                                                                                   data,
                                                                                   wml_pipelines_names,
@@ -321,7 +321,7 @@ class AutoPipelinesRuns(BaseAutoPipelinesRuns):
             training_result_reference = metadata.get('training_result_reference')
 
             # note: check for cloud
-            if isinstance(training_result_reference.location, S3Location):
+            if isinstance(training_result_reference.location, (S3Location, AssetLocation)):
                 run_id = training_result_reference.location._training_status.split('/')[-2]
 
             # WMLS
