@@ -119,21 +119,21 @@ class Experiments(WMLResource):
         if not self._ICP:
             if self._client.CLOUD_PLATFORM_SPACES:
                 response_experiment_post = requests.post(
-                    self._href_definitions.get_experiments_href(),
+                    self._client.service_instance._href_definitions.get_experiments_href(),
                     params=self._client._params(skip_for_create=True),
                     json=metaProps,
                     headers=self._client._get_headers()
                 )
             else:
                 response_experiment_post = requests.post(
-                    self._href_definitions.get_experiments_href(),
+                    self._client.service_instance._href_definitions.get_experiments_href(),
                     json=metaProps,
                     headers=self._client._get_headers()
                 )
         else:
             if self._client.ICP_PLATFORM_SPACES:
                 response_experiment_post = requests.post(
-                    self._href_definitions.get_experiments_href(),
+                    self._client.service_instance._href_definitions.get_experiments_href(),
                     json=metaProps,
                     params=self._client._params(skip_for_create=True),
                     headers=self._client._get_headers(),
@@ -141,7 +141,7 @@ class Experiments(WMLResource):
                 )
             else:
                 response_experiment_post = requests.post(
-                    self._href_definitions.get_experiments_href(),
+                    self._client.service_instance._href_definitions.get_experiments_href(),
                     json=metaProps,
                     headers=self._client._get_headers(),
                     verify=False
@@ -190,7 +190,7 @@ class Experiments(WMLResource):
 
         patch_payload = self.ConfigurationMetaNames._generate_patch_payload(details['entity'], changes, with_validation=True)
 
-        url = self._href_definitions.get_experiment_href(experiment_uid)
+        url = self._client.service_instance._href_definitions.get_experiment_href(experiment_uid)
         if not self._ICP:
             response = requests.patch(url, json=patch_payload, params = self._client._params(),headers=self._client._get_headers())
         else:
@@ -235,7 +235,7 @@ class Experiments(WMLResource):
         ##For CP4D, check if either spce or project ID is set
         self._client._check_if_either_is_set()
         experiment_uid = str_type_conv(experiment_uid)
-        url = self._href_definitions.get_experiments_href()
+        url = self._client.service_instance._href_definitions.get_experiments_href()
 
         return self._get_artifact_details(url, experiment_uid, limit, 'experiment')
 
@@ -370,7 +370,7 @@ class Experiments(WMLResource):
         experiment_uid = str_type_conv(experiment_uid)
         Experiments._validate_type(experiment_uid, u'experiment_uid', STR_TYPE, True)
 
-        url = self._href_definitions.get_experiment_href(experiment_uid)
+        url = self._client.service_instance._href_definitions.get_experiment_href(experiment_uid)
         if not self._ICP:
             response = requests.delete(url, params = self._client._params(),headers=self._client._get_headers())
         else:
@@ -436,7 +436,7 @@ class Experiments(WMLResource):
             raise WMLClientError(
                 u'Revision support is not there in this WML server. It is supported only from 3.1.0 onwards.')
         else:
-            url =self._href_definitions.get_experiments_href()
+            url =self._client.service_instance._href_definitions.get_experiments_href()
             return self._create_revision_artifact(url, experiment_id, 'experiments')
 
     @docstring_parameter({'str_type': STR_TYPE_NAME})
@@ -466,7 +466,7 @@ class Experiments(WMLResource):
             raise WMLClientError(
                 'Not supported. Revisions APIs are supported only for IBM Cloud Pak® for Data for Data 3.0 and above.')
         else:
-            url = self._href_definitions.get_experiment_href(experiment_uid)
+            url = self._client.service_instance._href_definitions.get_experiment_href(experiment_uid)
             return self._get_with_or_without_limit(url, limit=None, op_name="experiments",
                                                    summary=None, pre_defined=None, revision=rev_uid)
 
@@ -496,7 +496,7 @@ class Experiments(WMLResource):
             raise WMLClientError(
                 u'Revision support is not there in this WML server. It is supported only from 3.1.0 onwards.')
         else:
-            url = self._href_definitions.get_experiment_href(experiment_uid)
+            url = self._client.service_instance._href_definitions.get_experiment_href(experiment_uid)
             experiment_resources = self._get_artifact_details(url, "revisions", limit, 'model revisions')[u'resources']
             experiment_values = [
                 (m[u'metadata'][u'rev'], m[u'metadata'][u'name'], m[u'metadata'][u'created_at']) for m in
@@ -559,7 +559,7 @@ class Experiments(WMLResource):
         if rev is not None:
             clone_meta["rev"] = rev
 
-        url = self._href_definitions.get_experiment_href(experiment_uid)
+        url = self._client.service_instance._href_definitions.get_experiment_href(experiment_uid)
         if not self._ICP:
             response_post = requests.post(url, json=clone_meta,
                                           headers=self._client._get_headers())
