@@ -23,8 +23,7 @@ class BaseLocation(ABC):
     """
     Base class for storage Location.
     """
-
-    def to_dict(self) -> dict:
+    def to_dict(self, wml_client=None) -> dict:
         """Return a json dictionary representing this model."""
         return vars(self)
 
