@@ -15,6 +15,7 @@
 __all__ = [
     "DataConnection",
     "S3Connection",
+    "ConnectionAsset",
     "S3Location",
     "FSLocation",
     "AssetLocation",
@@ -24,7 +25,9 @@ __all__ = [
     "CloudAssetLocation",
     "DeploymentOutputAssetLocation",
     "NFSConnection",
-    "NFSLocation"
+    "NFSLocation",
+    'ConnectionAssetLocation',
+    "DatabaseLocation"
 ]
 
 import io
@@ -44,13 +47,16 @@ from ibm_watson_machine_learning.utils.autoai.enums import PredictionType, DataC
 from ibm_watson_machine_learning.utils.autoai.errors import (
     MissingAutoPipelinesParameters, UseWMLClient, MissingCOSStudioConnection, MissingProjectLib,
     HoldoutSplitNotSupported, InvalidCOSCredentials, MissingLocalAsset, InvalidIdType, NotWSDEnvironment,
-    NotExistingCOSResource
+    NotExistingCOSResource, InvalidDataAsset, CannotReadSavedRemoteDataBeforeFit
 )
 from ibm_watson_machine_learning.utils.autoai.watson_studio import get_project
 from ibm_watson_machine_learning.wml_client_error import MissingValue, ApiRequestFailure
 from .base_connection import BaseConnection
 from .base_data_connection import BaseDataConnection
 from .base_location import BaseLocation
+from ..flight.service import FlightService
+from ..flight.utils import get_data_asset_attachment, try_import_pyarrow
+from ..flight.errors import DataSourceTypeNotRecognized
 
 if TYPE_CHECKING:
     from ibm_watson_machine_learning.workspace import WorkSpace
@@ -62,7 +68,7 @@ class DataConnection(BaseDataConnection):
 
     Parameters
     ----------
-    connection: Union[S3Connection], required
+    connection: Union[S3Connection], optional
         connection parameters of specific type
 
     location: Union[S3Location, FSLocation, AssetLocation],
@@ -72,6 +78,9 @@ class DataConnection(BaseDataConnection):
         Names for node(s). If no value provided, data file name will be used as node name. If str will be passed,
         it will became node name. If multiple names will be passed, several nodes will have the same data connection
         (used for excel files with multiple sheets).
+
+    data_asset_id: str, optional,
+        Data asset ID if DataConnection should be pointing out to Data Asset.
     """
 
     def __init__(self,
@@ -83,14 +92,38 @@ class DataConnection(BaseDataConnection):
                                  'WSDAssetLocation',
                                  'CloudAssetLocation',
                                  'NFSLocation',
-                                 'DeploymentOutputAssetLocation'],
-                 connection: Optional[Union['S3Connection', 'NFSConnection']] = None,
-                 data_join_node_name: Union[str, List[str]] = None):
+                                 'DeploymentOutputAssetLocation',
+                                 'ConnectionAssetLocation',
+                                 'DatabaseLocation'] = None,
+                 connection: Optional[Union['S3Connection', 'NFSConnection', 'ConnectionAsset']] = None,
+                 data_join_node_name: Union[str, List[str]] = None,
+                 data_asset_id: str = None,
+                 connection_asset_id: str = None,
+                 **kwargs):
+        if data_asset_id is None and location is None:
+            raise MissingValue('location or data_asset_id', reason="Provide 'location' or 'data_asset_id'.")
+
+        elif data_asset_id is not None and location is not None:
+            raise ValueError("'data_asset_id' and 'location' cannot be specified together.")
+
+        elif data_asset_id is not None:
+            location = AssetLocation(asset_id=data_asset_id)
+
+            if kwargs.get('model_location') is not None:
+                location._model_location = kwargs['model_location']
+
+            if kwargs.get('training_status') is not None:
+                location._training_status = kwargs['training_status']
+
+        elif connection_asset_id is not None and isinstance(location, (S3Location, DatabaseLocation)):
+            connection = ConnectionAsset(connection_id=connection_asset_id)
+
         super().__init__()
 
         self.connection = connection
         self.location = location
 
+        # TODO: remove S3 implementation
         if isinstance(connection, S3Connection):
             self.type = DataConnectionTypes.S3
 
@@ -99,10 +132,14 @@ class DataConnection(BaseDataConnection):
             if self.connection is not None:
                 self.location.id = self.connection.asset_id
 
+        elif isinstance(connection, ConnectionAsset):
+            self.type = DataConnectionTypes.CA
+
         elif isinstance(location, FSLocation):
             self.type = DataConnectionTypes.FS
 
-        elif isinstance(location, (AssetLocation, CP4DAssetLocation, WMLSAssetLocation, CloudAssetLocation, WSDAssetLocation, DeploymentOutputAssetLocation)):
+        elif isinstance(location, (AssetLocation, CP4DAssetLocation, WMLSAssetLocation, CloudAssetLocation,
+                                   WSDAssetLocation, DeploymentOutputAssetLocation)):
             self.type = DataConnectionTypes.DS
 
         self.auto_pipeline_params = {}  # note: needed parameters for recreation of autoai holdout split
@@ -113,7 +150,9 @@ class DataConnection(BaseDataConnection):
 
         # note: make data connection id as a location path for OBM + KB
         if data_join_node_name is None:
-            if self.type == DataConnectionTypes.S3:
+            # TODO: remove S3 implementation
+            if self.type == DataConnectionTypes.S3 or (
+                    self.type == DataConnectionTypes.CA and hasattr(location, 'path')):
                 self.id = location.path
 
             else:
@@ -161,11 +200,9 @@ class DataConnection(BaseDataConnection):
                             if ('url' in connection_details and 'access_key' in connection_details and
                                     'secret_key' in connection_details and 'bucket' in connection_details):
                                 data_connections.append(
-                                    cls(connection=S3Connection(endpoint_url=connection_details['url'],
-                                                                access_key_id=connection_details['access_key'],
-                                                                secret_access_key=connection_details['secret_key']),
-                                        location=S3Location(bucket=connection_details['bucket'],
-                                                            path=path))
+                                    cls(connection=ConnectionAsset(id=connection_details['id']),
+                                        location=ConnectionAssetLocation(bucket=connection_details['bucket'],
+                                                                         file_name=path))
                                 )
 
             if data_connections:
@@ -213,7 +250,12 @@ class DataConnection(BaseDataConnection):
         else:
             _dict['connection'] = {}
 
-        _dict['location'] = deepcopy(self.location.to_dict())
+        try:
+            _dict['location'] = deepcopy(self.location.to_dict(self._wml_client))
+
+        except AttributeError:
+            _dict['location'] = {}
+
         return _dict
 
     def __repr__(self):
@@ -236,7 +278,10 @@ class DataConnection(BaseDataConnection):
         -------
         DataConnection
         """
+        # TODO: remove S3 implementation
         if _dict['type'] == DataConnectionTypes.S3:
+            warn(message="S3 DataConnection is depreciated! Please use data_asset_id instead.")
+
             data_connection: 'DataConnection' = cls(
                 connection=S3Connection(
                     access_key_id=_dict['connection']['access_key_id'],
@@ -253,10 +298,27 @@ class DataConnection(BaseDataConnection):
                 location=FSLocation._set_path(path=_dict['location']['path'])
             )
         elif _dict['type'] == DataConnectionTypes.CA:
-            data_connection: 'DataConnection' = cls(
-                connection=NFSConnection(asset_id=_dict['connection']['asset_id']),
-                location=NFSLocation(path=_dict['location']['path'])
-            )
+            if _dict['location'].get('path') and _dict['location'].get('bucket'):
+                data_connection: 'DataConnection' = cls(
+                    connection_asset_id=_dict['connection']['id'],
+                    location=S3Location(
+                        bucket=_dict['location']['bucket'],
+                        path=_dict['location']['path']
+                    )
+                )
+
+            elif _dict['location'].get('schema_name') and _dict['location'].get('table_name'):
+                data_connection: 'DataConnection' = cls(
+                    connection_asset_id=_dict['connection']['id'],
+                    location=DatabaseLocation(schema_name=_dict['location']['schema_name'],
+                                              table_name=_dict['location']['table_name'])
+                )
+
+            else:
+                data_connection: 'DataConnection' = cls(
+                    connection=NFSConnection(asset_id=_dict['connection']['asset_id']),
+                    location=NFSLocation(path=_dict['location']['path'])
+                )
         else:
             data_connection: 'DataConnection' = cls(
                 location=AssetLocation._set_path(href=_dict['location']['href'])
@@ -296,6 +358,14 @@ class DataConnection(BaseDataConnection):
             (only if only_holdout == True and auto_pipeline_params was passed)
         """
 
+        if self.type == DataConnectionTypes.DS or self.type == DataConnectionTypes.CA:
+            if self._wml_client is None:
+                try:
+                    from project_lib import Project
+
+                except ModuleNotFoundError:
+                    raise NotImplementedError(f"This functionality can be run only on Watson Studio.")
+
         if with_holdout_split:
             print("\"with_holdout_split\" option is depreciated.")
             warn("\"with_holdout_split\" option is depreciated.")
@@ -318,7 +388,11 @@ class DataConnection(BaseDataConnection):
         # --- end note
 
         data = DataFrame()
+
+        # TODO: Remove S3 implementation
         if self.type == DataConnectionTypes.S3:
+            warn(message="S3 DataConnection is depreciated! Please use data_asset_id instead.")
+
             cos_client = self._init_cos_client()
 
             try:
@@ -338,7 +412,32 @@ class DataConnection(BaseDataConnection):
             if self._obm:
                 raise NotImplementedError("Multiple files for CP4D / WML Server is not yet supported.")
 
-            data = self._download_training_data_from_data_asset_storage()
+            try:
+                if self._check_if_connection_asset_is_s3():
+                    cos_client = self._init_cos_client()
+                    data = self._download_data_from_cos(cos_client=cos_client)
+                else:
+                    data = self._download_training_data_from_data_asset_storage()
+
+            except NotImplementedError as e:
+                raise e
+
+            except FileNotFoundError as e:
+                raise e
+
+            except Exception:
+                data_location = self.location.to_dict()
+                data_location.update({'type': self.type})
+
+                try_import_pyarrow()
+
+                flight_service = FlightService(
+                    wml_client=self._wml_client,
+                    params=self.auto_pipeline_params,
+                    data_location=data_location,
+                )
+
+                data = flight_service.read()
 
         elif self.type == DataConnectionTypes.FS:
 
@@ -348,7 +447,36 @@ class DataConnection(BaseDataConnection):
                 data = self._download_training_data_from_file_system()
 
         elif self.type == DataConnectionTypes.CA:
-            data = self._download_data_from_nfs_connection()
+
+            if self._check_if_connection_asset_is_s3():
+                cos_client = self._init_cos_client()
+
+                try:
+                    if self._obm:
+                        data = self._download_obm_data_from_cos(cos_client=cos_client)
+
+                    else:
+                        data = self._download_data_from_cos(cos_client=cos_client)
+
+                except Exception as cos_access_exception:
+                    raise ConnectionError(f"Unable to access data object in cloud object storage with credentials supplied. "
+                                          f"Error: {cos_access_exception}")
+            else:
+                try:
+                    data = self._download_data_from_nfs_connection()
+
+                except Exception:
+                    try_import_pyarrow()
+
+                    flight_service = FlightService(
+                        wml_client=self._wml_client,
+                        params=self.auto_pipeline_params,
+                        data_location={'location': self.location.to_dict(),
+                                       'type': self.type,
+                                       "connection": self.connection.to_dict()},
+                    )
+
+                    data = flight_service.read()
 
         if isinstance(data, DataFrame) and 'Unnamed: 0' in data.columns.tolist():
             data.drop(['Unnamed: 0'], axis=1, inplace=True)
@@ -398,7 +526,7 @@ class DataConnection(BaseDataConnection):
 
         return data
 
-    def write(self, data: Union[str, 'DataFrame'], remote_name: str) -> None:
+    def write(self, data: Union[str, 'DataFrame'], remote_name: str = None) -> None:
         """
         Upload file to a remote data storage.
 
@@ -410,7 +538,12 @@ class DataConnection(BaseDataConnection):
         remote_name: str, required
             Name that dataset should be stored with in remote data storage.
         """
+        # TODO: Remove S3 implementation
         if self.type == DataConnectionTypes.S3:
+            warn(message="S3 DataConnection is depreciated! Please use data_asset_id instead.")
+            if remote_name is None:
+                raise MissingValue('remote_name')
+
             cos_resource_client = self._init_cos_client()
             if isinstance(data, str):
                 with open(data, "rb") as file_data:
@@ -430,12 +563,51 @@ class DataConnection(BaseDataConnection):
             else:
                 raise TypeError("data should be either of type \"str\" or \"pandas.DataFrame\"")
 
+        elif self.type == DataConnectionTypes.CA:
+            if self._check_if_connection_asset_is_s3():
+                cos_resource_client = self._init_cos_client()
+                if isinstance(data, str):
+                    with open(data, "rb") as file_data:
+                        cos_resource_client.Object(self.location.bucket, remote_name).upload_fileobj(
+                            Fileobj=file_data)
+
+                elif isinstance(data, DataFrame):
+                    # note: we are saving csv in memory as a file and stream it to the COS
+                    buffer = io.StringIO()
+                    data.to_csv(buffer, index=False)
+                    buffer.seek(0)
+
+                    with buffer as f:
+                        cos_resource_client.Object(self.location.bucket, remote_name).upload_fileobj(
+                            Fileobj=io.BytesIO(bytes(f.read().encode())))
+
+                else:
+                    raise TypeError("data should be either of type \"str\" or \"pandas.DataFrame\"")
+
+            else:
+                try_import_pyarrow()
+
+                flight_service = FlightService(
+                    wml_client=self._wml_client,
+                    params=self.auto_pipeline_params,
+                    data_location={'location': self.location.to_dict(),
+                                   'type': self.type,
+                                   "connection": self.connection.to_dict()},
+                )
+
+                if isinstance(data, str):
+                    raise TypeError(f"'data' should be of pandas.DataFrame type if "
+                                    f"you want to store it with connection asset.")
+
+                elif isinstance(data, DataFrame):
+                    flight_service.write_data(data)
+
         elif self.type == DataConnectionTypes.DS:
             raise UseWMLClient('DataConnection.write()',
                                reason="If you want to upload any data to CP4D instance, "
                                       "firstly please get the WML client by calling "
                                       "\"client = WMLInstance().get_client()\" "
-                                      "then call the method: \"client.data_asset.create()\"")
+                                      "then call the method: \"client.data_assets.create()\"")
 
     def _init_cos_client(self) -> 'resource':
         """Initiate COS client for further usage."""
@@ -467,6 +639,7 @@ class DataConnection(BaseDataConnection):
             raise NotExistingCOSResource(self.location.bucket, self.location.path)
 
 
+# TODO: Remove S3 Implementation for connection
 class S3Connection(BaseConnection):
     """
     Connection class to COS data storage in S3 format.
@@ -495,6 +668,8 @@ class S3Connection(BaseConnection):
     def __init__(self, endpoint_url: str, access_key_id: str = None, secret_access_key: str = None,
                  api_key: str = None, service_name: str = None, auth_endpoint: str = None) -> None:
 
+        warn(message="S3 DataConnection is depreciated! Please use data_asset_id instead.")
+
         if (access_key_id is None or secret_access_key is None) and (api_key is None or auth_endpoint is None):
             raise InvalidCOSCredentials(reason='You need to specify (access_key_id and secret_access_key) or'
                                                '(api_key and auth_endpoint)')
@@ -586,10 +761,12 @@ class FSLocation(BaseLocation):
         # note if path is not file then returned size is 0
         try:
             # note: try to get file size from remote server
-            url = f"{workspace.wml_client.wml_credentials['url']}/v2/asset_files/{self.path.split('/assets/')[-1]}"
-            path_info_response = requests.head(url, headers=workspace.wml_client._get_headers(), params=workspace.wml_client._params(), verify=False)
+            url = workspace.wml_client.service_instance._href_definitions.get_wsd_model_attachment_href() \
+                  + f"/{self.path.split('/assets/')[-1]}"
+            path_info_response = requests.head(url, headers=workspace.wml_client._get_headers(),
+                                               params=workspace.wml_client._params(), verify=False)
             if path_info_response.status_code != 200:
-                raise ApiRequestFailure(u"Failure during getting path details",path_info_response)
+                raise ApiRequestFailure(u"Failure during getting path details", path_info_response)
             path_info = path_info_response.headers
             if 'X-Asset-Files-Type' in path_info and path_info['X-Asset-Files-Type'] == 'file':
                 size = path_info['X-Asset-Files-Size']
@@ -607,16 +784,47 @@ class AssetLocation(BaseLocation):
 
     def __init__(self, asset_id: str) -> None:
         self._wsd = self._is_wsd()
+        self.href = None
+        self._initial_asset_id = asset_id
 
         if self._wsd:
-            self.href = f'/v2/assets/{asset_id}'
             self._asset_name = None
             self._asset_id = None
             self._local_asset_path = None
         else:
-            self.href = f'/v2/assets/{asset_id}?' + '{option}' + '=' + '{id}'
             self.id = asset_id
 
+    def _get_connection_id(self, client) -> str:
+        asset_details = client.data_assets.get_details(self.id)
+
+        if 'attachment_id' in asset_details['metadata']:
+            attachment_id = asset_details['metadata']['attachment_id']
+
+        else:
+            attachment_id = asset_details['attachments'][0]['id']
+
+        attachment_url = client.service_instance._href_definitions.get_data_asset_href(self.id)
+        attachment_url = f"{attachment_url}/attachments/{attachment_id}"
+
+        if client.ICP:
+            attachment = requests.get(attachment_url, headers=client._get_headers(),
+                                      params=client._params(), verify=False)
+
+        else:
+            attachment = requests.get(attachment_url, headers=client._get_headers(),
+                                      params=client._params())
+
+        if attachment.status_code != 200:
+            raise ApiRequestFailure(u"Failure during getting attachment details", attachment)
+
+        attachment_content = attachment.json()
+
+        if 'connection_id' in attachment_content:
+            return attachment_content['connection_id']
+
+        else:
+            raise InvalidDataAsset()
+
     @classmethod
     def _is_wsd(cls):
         if os.environ.get('USER_ACCESS_TOKEN'):
@@ -645,9 +853,10 @@ class AssetLocation(BaseLocation):
             return self._wsd_get_file_size()
         else:
             verify_request = False if workspace.wml_client.ICP else True
-            asset_info_response = requests.get(workspace.wml_client.data_assets._href_definitions.get_data_asset_href(self.id),
-                                                params= workspace.wml_client._params(),
-                                                headers= workspace.wml_client._get_headers(), verify=verify_request)
+            asset_info_response = requests.get(
+                workspace.wml_client.service_instance._href_definitions.get_data_asset_href(self.id),
+                params=workspace.wml_client._params(),
+                headers=workspace.wml_client._get_headers(), verify=verify_request)
             if asset_info_response.status_code != 200:
                 raise ApiRequestFailure(u"Failure during getting asset details", asset_info_response)
             return asset_info_response.json()['metadata'].get('size')
@@ -664,7 +873,7 @@ class AssetLocation(BaseLocation):
 
         # note: reuse local asset_id when object is reused more times
         if self._asset_id is None:
-            local_asset_id = self.href.split('/')[3].split('?space_id')[0]
+            local_asset_id = self._initial_asset_id
 
         else:
             local_asset_id = self._asset_id
@@ -709,7 +918,7 @@ class AssetLocation(BaseLocation):
         project = get_project()
         return project.get_files()
 
-    def to_dict(self) -> dict:
+    def to_dict(self, wml_client=None) -> dict:
         """Return a json dictionary representing this model."""
         _dict = vars(self).copy()
 
@@ -720,9 +929,82 @@ class AssetLocation(BaseLocation):
             del _dict['_asset_id']
             del _dict['_local_asset_path']
 
+        if self.href is None:
+            if wml_client:
+                _dict['href'] = wml_client.service_instance._href_definitions.get_base_asset_href(
+                    self._initial_asset_id)
+            else:
+                _dict['href'] = f'/v2/assets/{self._initial_asset_id}'
+
+            if not self._wsd:
+                if wml_client:
+                    if wml_client.default_space_id:
+                        _dict['href'] = f'{_dict["href"]}?space_id={wml_client.default_space_id}'
+                    else:
+                        _dict['href'] = f'{_dict["href"]}?project_id={wml_client.default_project_id}'
+
+        del _dict['_initial_asset_id']
+
         return _dict
 
 
+class ConnectionAssetLocation(BaseLocation):
+    """
+        Connection class to COS data storage.
+
+        Parameters
+        ----------
+        bucket: str, required
+            COS bucket name
+
+        file_name: str, required
+            COS data path in the bucket
+
+        model_location: str, optional
+            Path to the pipeline model in the COS.
+
+        training_status: str, optional
+            Path t the training status json in COS.
+        """
+
+    def __init__(self, bucket: str, file_name: str, **kwargs) -> None:
+        self.bucket = bucket
+        self.file_name = file_name
+        self.path = file_name
+
+        if kwargs.get('model_location') is not None:
+            self._model_location = kwargs['model_location']
+
+        if kwargs.get('training_status') is not None:
+            self._training_status = kwargs['training_status']
+
+    def _get_file_size(self, cos_resource_client: 'resource') -> 'int':
+        try:
+            size = cos_resource_client.Object(self.bucket, self.path).content_length
+        except ClientError:
+            size = 0
+        return size
+
+    def to_dict(self) -> dict:
+        """Return a json dictionary representing this model."""
+        return vars(self)
+
+
+class ConnectionAsset(BaseConnection):
+    """
+    Connection class for Connection Asset
+
+    Parameters
+    ----------
+    connection_id: str, required
+        Connection asset ID
+    """
+
+    def __init__(self, connection_id: str):
+        self.id = connection_id
+        self.asset_id = connection_id
+
+
 class NFSConnection(BaseConnection):
     """
     Connection class to file storage in CP4D of NFS format.
@@ -732,6 +1014,7 @@ class NFSConnection(BaseConnection):
     connection_id: str, required
         Connection ID from the project on CP4D
     """
+
     def __init__(self, asset_id: str):
         self.asset_id = asset_id
 
@@ -745,6 +1028,7 @@ class NFSLocation(BaseLocation):
     path: str, required
         Data path form the project on CP4D.
     """
+
     def __init__(self, path: str):
         self.path = path
         self.id = None
@@ -775,7 +1059,7 @@ class CP4DAssetLocation(AssetLocation):
     def __init__(self, asset_id: str) -> None:
         super().__init__(asset_id)
         warning_msg = ("Depreciation Warning: Class CP4DAssetLocation is no longer supported and will be removed."
-                        "Use AssetLocation instead.")
+                       "Use AssetLocation instead.")
         print(warning_msg)
 
     def _get_file_size(self, workspace: 'WorkSpace', *args) -> 'int':
@@ -795,11 +1079,11 @@ class WMLSAssetLocation(AssetLocation):
     def __init__(self, asset_id: str) -> None:
         super().__init__(asset_id)
         warning_msg = ("Depreciation Warning: Class WMLSAssetLocation is no longer supported and will be removed."
-                        "Use AssetLocation instead.")
+                       "Use AssetLocation instead.")
         print(warning_msg)
 
     def _get_file_size(self, workspace: 'WorkSpace', *args) -> 'int':
-        return  super()._get_file_size(workspace)
+        return super()._get_file_size(workspace)
 
 
 class CloudAssetLocation(AssetLocation):
@@ -811,11 +1095,12 @@ class CloudAssetLocation(AssetLocation):
     asset_id: str, required
         Asset ID of the file loaded on space on Cloud.
     """
+
     def __init__(self, asset_id: str) -> None:
         super().__init__(asset_id)
         self.href = self.href
         warning_msg = ("Depreciation Warning: Class CloudAssetLocation is no longer supported and will be removed."
-                        "Use AssetLocation instead.")
+                       "Use AssetLocation instead.")
         print(warning_msg)
 
     def _get_file_size(self, workspace: 'WorkSpace', *args) -> 'int':
@@ -833,10 +1118,11 @@ class WSDAssetLocation(BaseLocation):
     """
 
     def __init__(self, asset_id: str) -> None:
-        self.href = f'/v2/assets/{asset_id}'
+        self.href = None
         self._asset_name = None
         self._asset_id = None
         self._local_asset_path = None
+        self._initial_asset_id = asset_id
 
         warning_msg = ("Depreciation Warning: Class WSDAssetLocation is no longer supported and will be removed."
                        "Use AssetLocation instead.")
@@ -888,13 +1174,21 @@ class WSDAssetLocation(BaseLocation):
         location.href = href
         return location
 
-    def to_dict(self) -> dict:
+    def to_dict(self, wml_client=None) -> dict:
         """Return a json dictionary representing this model."""
         _dict = vars(self).copy()
         del _dict['_asset_name']
         del _dict['_asset_id']
         del _dict['_local_asset_path']
 
+        if self.href is None:
+            if wml_client:
+                _dict['href'] = wml_client.service_instance._href_definitions.get_base_asset_href(self._initial_asset_id)
+            else:
+                _dict['href'] = f'/v2/assets/{self._initial_asset_id}'
+
+        del _dict['_initial_asset_id']
+
         return _dict
 
     def _get_file_size(self) -> 'int':
@@ -919,3 +1213,23 @@ class DeploymentOutputAssetLocation(BaseLocation):
         self.name = name
         self.description = description
 
+
+class DatabaseLocation(BaseLocation):
+    """
+    Location class to Database.
+
+    Parameters
+    ----------
+    schema_name: str, required
+        Database schema name.
+
+    table_name: str, required
+        Database table name
+    """
+
+    def __init__(self, schema_name: str, table_name: str, **kwargs) -> None:
+        self.schema_name = schema_name
+        self.table_name = table_name
+
+    def _get_file_size(self) -> None:
+        raise NotImplementedError()
