@@ -30,6 +30,8 @@ class ServiceInstanceNewPlan:
         self._logger = logging.getLogger(__name__)
         self._client = client
         self._wml_credentials = client.wml_credentials
+        self._expiration_datetime = None
+        self._is_iam_token = None
 
         if self._client.ICP_PLATFORM_SPACES:
             if self.get_instance_id() == 'openshift' or self.get_instance_id() == 'wml_local':
@@ -45,6 +47,7 @@ class ServiceInstanceNewPlan:
                                                  self._client.PLATFORM_URL,
                                                  self._client.CAMS_URL,
                                                  self._client.ICP_PLATFORM_SPACES,
+                                                 git_based_project=self._client.project_type == "local_git_storage"
                                                  )
 
         self._client.wml_token = self._create_token()
@@ -227,6 +230,9 @@ class ServiceInstanceNewPlan:
         self._client.wml_token = self._get_cpd_token_from_request()
 
     def _get_expiration_datetime(self):
+        if self._expiration_datetime is not None:
+            return self._expiration_datetime
+
         token_parts = self._client.wml_token.split('.')
         token_padded = token_parts[1] + '=' * (len(token_parts[1]) % 4)
         token_info = json.loads(base64.b64decode(token_padded).decode('utf-8'))
@@ -235,6 +241,9 @@ class ServiceInstanceNewPlan:
         return datetime.fromtimestamp(token_expire)
 
     def _is_iam(self):
+        if self._is_iam_token is not None:
+            return self._is_iam_token
+
         token_parts = self._client.wml_token.split('.')
         token_padded = token_parts[1] + '=' * (len(token_parts[1]) % 4)
         token_info = json.loads(base64.b64decode(token_padded).decode('utf-8'))
@@ -259,6 +268,8 @@ class ServiceInstanceNewPlan:
 
         if response.status_code == 200:
             token = response.json().get(u'access_token')
+            self._expiration_datetime = None
+            self._is_iam_token = None
         else:
             raise WMLClientError(u'Error during getting IAM Token.', response)
         return token
@@ -295,6 +306,18 @@ class ServiceInstanceNewPlan:
             return f'{{\"username\": \"{self.get_username()}\", \"password\": \"{self.get_password()}\"}}'
 
 
+    def _get_cpd_bedrock_auth_data(self):
+        """
+        Get data required for generation of token.
+
+        **Output**
+
+            **returns**: String representing a dictionary of authentication credentials\n
+            **return type**: str
+        """
+        return f'grant_type=password&username={self.get_username()}&password={self.get_password()}&scope=openid'
+
+
     def _get_cpd_token_from_request(self):
         """
         Send a request for token on CPD.
@@ -303,15 +326,48 @@ class ServiceInstanceNewPlan:
             **returns**: Newly created token if returned if no errors occurred.\n
             **return type**: str\n
         """
-        token_url = self._href_definitions.get_cpd_token_endpoint_href()
-        response = requests.post(token_url,
-                                 headers={
-                                     'Content-Type': 'application/json'
-                                 },
-                                 data=self._get_cpd_auth_pair(),
-                                 verify=False)
+        if self._client.ICP_40 and 'bedrock_url' in self._client.wml_credentials: # TODO change condition here later
+            bedrock_url = self._href_definitions.get_cpd_bedrock_token_endpoint_href()
+            response = requests.post(bedrock_url,
+                                     headers={
+                                         'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8'
+                                     },
+                                     data=self._get_cpd_bedrock_auth_data(),
+                                     verify=False)
+
+            if response.status_code != 200:
+                raise WMLClientError(u'Error during refreshing the token.', response)
+
+            iam_token = response.json()['access_token']
+            self._expiration_datetime = datetime.now() + timedelta(milliseconds=response.json()['expires_in'])
+            self._is_iam_token = True
+            #refresh_token = response.json()['refresh_token']
+
+            token_url = self._href_definitions.get_cpd_validation_token_endpoint_href()
+            response = requests.get(token_url,
+                                     headers={
+                                         'username': 'admin',
+                                         'iam-token': iam_token
+                                     },
+                                     verify=False)
+
+            if response.status_code == 200:
+                return response.json()['accessToken']
+            else:
+                raise WMLClientError(u'Error during refreshing the token.', response)
 
-        if response.status_code == 200:
-            return response.json().get(u'token')
         else:
-            raise WMLClientError(u'Error during refreshing the token.', response)
+            token_url = self._href_definitions.get_cpd_token_endpoint_href()
+            response = requests.post(token_url,
+                                     headers={
+                                         'Content-Type': 'application/json'
+                                     },
+                                     data=self._get_cpd_auth_pair(),
+                                     verify=False)
+
+            if response.status_code == 200:
+                self._expiration_datetime = None
+                self._is_iam_token = None
+                return response.json().get(u'token')
+            else:
+                raise WMLClientError(u'Error during refreshing the token.', response)
