@@ -705,12 +705,12 @@ class ModelCollection:
                     type = training_ref_obj.get('type', None)
                     connection = training_ref_obj.get('connection', None)
                     location = training_ref_obj.get('location', None)
-                    if artifact.meta.prop(MetaNames.TRAINING_DATA_SCHEMA) is not None:
+                    schema = training_ref_obj.get('schema', None)
+                    if schema is None and artifact.meta.prop(MetaNames.TRAINING_DATA_SCHEMA) is not None:
                         training_schema = artifact.meta.prop(MetaNames.TRAINING_DATA_SCHEMA)
                         training_schema["id"] = "1"
                         schema = training_schema
-                    else:
-                        schema = training_ref_obj.get('schema', None)
+
                     if v4_cloud:
                         training_ref = {"id": training_ref_obj.get('id', i),
                                         "type": type,
@@ -812,6 +812,8 @@ class ModelCollection:
             output_schema = [artifact.meta.prop(MetaNames.OUTPUT_DATA_SCHEMA)]
         if len(input_schema) != 0 or len(output_schema) != 0:
             schemas = ModelSchemas(input_schema,output_schema)
+        elif artifact.meta.prop('schemas') is not None:
+            schemas = artifact.meta.prop('schemas')
 
         tags_data_list = artifact.meta.prop(MetaNames.TAGS)
         if isinstance(artifact.meta.prop(MetaNames.TAGS), str):
@@ -1089,14 +1091,6 @@ class ModelCollection:
         params = params
         headers = headers
 
-        #define the base path url
-        cams_asset_files = u'{}/v2/asset_files/'
-        cams_asset_type = u'{}/v2/asset_types'
-        atype_url = cams_asset_type.format(url)
-        cams_asset = u'{}/v2/assets'
-        asset_url = cams_asset.format(url)
-        asset_files_url = cams_asset_files.format(url)
-
         try:
             ## create model asset type
             atype_body = {
@@ -1107,7 +1101,7 @@ class ModelCollection:
             }
             atype_payload = json.dumps(atype_body, separators=(',', ':'))
             asset_type_response = requests.post(
-                atype_url,
+                self.client.service_instance._href_definitions.get_wsd_asset_type_href(),
                 params=params,
                 data=atype_payload,
                 headers=aheaders,
@@ -1118,7 +1112,7 @@ class ModelCollection:
                 raise Exception("Failed to create asset type. Try again.")
 
             create_response = requests.post(
-                asset_url,
+                self.client.service_instance._href_definitions.get_assets_href(),
                 params=params,
                 json=input_payload,
                 headers=headers,
@@ -1138,9 +1132,9 @@ class ModelCollection:
             if create_response.status_code == 201:
                 asset_uid = create_response.json()["metadata"]["asset_id"]
                 file_name_to_attach = 'wml_model_attachment'
-                content_upload_url = asset_files_url + \
+                content_upload_url = self.client.service_instance._href_definitions.get_wsd_model_attachment_href() + '/' + \
                                      urllib.parse.quote("wml_model/" + asset_uid + "/" + file_name_to_attach, safe='')
-                attach_url = asset_url + "/" + urllib.parse.quote(asset_uid + "/attachments")
+                attach_url = self.client.service_instance._href_definitions.get_attachments_href(asset_uid)
                 fdata = content_stream
                 response = requests.put(
                     content_upload_url,
