@@ -61,10 +61,10 @@ class Script(WMLResource):
 
 
         if not self._ICP:
-            response = requests.get(self._href_definitions.get_data_asset_href(script_uid), params=self._client._params(),
+            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(script_uid), params=self._client._params(),
                                     headers=self._client._get_headers())
         else:
-            response = requests.get(self._href_definitions.get_data_asset_href(script_uid), params=self._client._params(),
+            response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(script_uid), params=self._client._params(),
                                       headers=self._client._get_headers(), verify=False)
         if response.status_code == 200:
             response = self._get_required_element_from_response(self._handle_response(200, u'get asset details', response))
@@ -347,7 +347,7 @@ class Script(WMLResource):
         else:
             if not self._ICP:
                 creation_response = requests.post(
-                        self._href_definitions.get_assets_href(),
+                        self._client.service_instance._href_definitions.get_assets_href(),
                         headers=self._client._get_headers(),
                         params = self._client._params(),
                         json=asset_meta
@@ -355,7 +355,7 @@ class Script(WMLResource):
             else:
                 if self._client.ICP_PLATFORM_SPACES:
                     creation_response = requests.post(
-                        self._href_definitions.get_data_assets_href(),
+                        self._client.service_instance._href_definitions.get_data_assets_href(),
                         headers=self._client._get_headers(),
                         json=asset_meta,
                         params=self._client._params(),
@@ -363,7 +363,7 @@ class Script(WMLResource):
                     )
                 else:
                     asset_type_response = requests.post(
-                        self._wml_credentials['url'] + "/v2/asset_types?",
+                        self._client.service_instance._href_definitions.get_wsd_asset_type_href() + '?',
                         headers=self._client._get_headers(),
                         json=base_script_asset,
                         params=self._client._params(),
@@ -371,7 +371,7 @@ class Script(WMLResource):
                     )
                     if asset_type_response.status_code == 201 or asset_type_response.status_code == 409:
                         creation_response = requests.post(
-                            self._href_definitions.get_data_assets_href(),
+                            self._client.service_instance._href_definitions.get_data_assets_href(),
                             headers=self._client._get_headers(),
                             json=asset_meta,
                             params=self._client._params(),
@@ -389,14 +389,14 @@ class Script(WMLResource):
 
                 if not self._ICP:
                     attachment_response = requests.post(
-                        self._href_definitions.get_attachments_href(asset_id),
+                        self._client.service_instance._href_definitions.get_attachments_href(asset_id),
                         headers=self._client._get_headers(),
                         params=self._client._params(),
                         json=attachment_meta
                     )
                 else:
                     attachment_response = requests.post(
-                        self._wml_credentials['url']+"/v2/assets/"+asset_id+"/attachments",
+                        self._client.service_instance._href_definitions.get_attachments_href(asset_id),
                         headers=self._client._get_headers(),
                         json=attachment_meta,
                         params=self._client._params(),
@@ -427,15 +427,15 @@ class Script(WMLResource):
                         # Step4: Complete attachment
                         if not self._ICP:
                             complete_response = requests.post(
-                                # self._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
-                                self._href_definitions.get_attachment_complete_href(asset_id, attachment_id),
+                                # self._client.service_instance._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
+                                self._client.service_instance._href_definitions.get_attachment_complete_href(asset_id, attachment_id),
                                 headers=self._client._get_headers(),
                                 params = self._client._params()
 
                             )
                         else:
                             complete_response = requests.post(
-                                self._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
+                                self._client.service_instance._href_definitions.get_attachment_href(asset_id,attachment_id)+"/complete",
                                 headers=self._client._get_headers(),
                                 params=self._client._params(),
                                 verify=False
@@ -478,7 +478,7 @@ class Script(WMLResource):
         """
 
         Script._validate_type(limit, u'limit', int, False)
-        href = self._href_definitions.get_search_script_href()
+        href = self._client.service_instance._href_definitions.get_search_script_href()
 
         data = {
                 "query": "*:*"
@@ -540,18 +540,18 @@ class Script(WMLResource):
 
         import urllib
         if not self._ICP:
-            asset_response = requests.get(self._href_definitions.get_asset_href(asset_uid),
+            asset_response = requests.get(self._client.service_instance._href_definitions.get_asset_href(asset_uid),
                                           params=params,
                                           headers=self._client._get_headers())
         else:
-            asset_response = requests.get(self._href_definitions.get_data_asset_href(asset_uid),
+            asset_response = requests.get(self._client.service_instance._href_definitions.get_data_asset_href(asset_uid),
                                           params=params,
                                           headers=self._client._get_headers(), verify=False)
         asset_details = self._handle_response(200, u'get assets', asset_response)
 
         if self._WSD:
             attachment_url = asset_details['attachments'][0]['object_key']
-            artifact_content_url = self._href_definitions.get_wsd_model_attachment_href() + \
+            artifact_content_url = self._client.service_instance._href_definitions.get_wsd_model_attachment_href() + \
                                    urllib.parse.quote('script/' + attachment_url, safe='')
 
             r = requests.get(artifact_content_url, params=self._client._params(), headers=self._client._get_headers(),
@@ -570,10 +570,10 @@ class Script(WMLResource):
         else:
             attachment_id = asset_details["attachments"][0]["id"]
             if not self._ICP:
-                response = requests.get(self._href_definitions.get_attachment_href(asset_uid,attachment_id), params=params,
+                response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id), params=params,
                                         headers=self._client._get_headers())
             else:
-                response = requests.get(self._href_definitions.get_attachment_href(asset_uid,attachment_id), params=params,
+                response = requests.get(self._client.service_instance._href_definitions.get_attachment_href(asset_uid,attachment_id), params=params,
                                           headers=self._client._get_headers(), verify=False)
             if response.status_code == 200:
                 attachment_signed_url = response.json()["url"]
@@ -726,7 +726,7 @@ class Script(WMLResource):
         updated_details = None
         details = None
 
-        url = self._href_definitions.get_asset_href(script_uid)
+        url = self._client.service_instance._href_definitions.get_asset_href(script_uid)
 
         # STEPS
         # STEP 1. Get existing metadata
@@ -800,7 +800,7 @@ class Script(WMLResource):
                                              'value': '{base_id:' + meta_props[u'software_spec_uid'] + '}'}]
 
             if meta_patch_payload:
-                meta_patch_url = self._href_definitions.get_asset_href(script_uid)
+                meta_patch_url = self._client.service_instance._href_definitions.get_asset_href(script_uid)
 
                 if not self._ICP:
                     response_patch = requests.patch(meta_patch_url,
@@ -816,7 +816,7 @@ class Script(WMLResource):
                 updated_details = self._handle_response(200, u'script patch', response_patch)
 
             if entity_patch_payload:
-                entity_patch_url = self._href_definitions.get_asset_href(script_uid) + '/attributes/script'
+                entity_patch_url = self._client.service_instance._href_definitions.get_asset_href(script_uid) + '/attributes/script'
 
                 if not self._ICP:
                     response_patch = requests.patch(entity_patch_url,
@@ -847,7 +847,7 @@ class Script(WMLResource):
             self._update_msg(updated_details)
 
         # Have to fetch again to reflect updated asset and attachment ids
-        url = self._href_definitions.get_asset_href(script_uid)
+        url = self._client.service_instance._href_definitions.get_asset_href(script_uid)
 
         if not self._ICP:
             response = requests.get(
@@ -929,10 +929,10 @@ class Script(WMLResource):
                 u'Cannot delete script that has existing deployments. Please delete all associated deployments and try again')
 
         if not self._ICP:
-            response = requests.delete(self._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                     headers=self._client._get_headers())
         else:
-            response = requests.delete(self._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                       headers=self._client._get_headers(), verify=False)
         if response.status_code == 200:
             return self._get_required_element_from_response(response.json())
@@ -1032,7 +1032,7 @@ class Script(WMLResource):
         script_uid = str_type_conv(script_uid)
         Script._validate_type(script_uid, u'script_uid', STR_TYPE, True)
 
-        url = self._href_definitions.get_asset_href(script_uid) + "/revisions"
+        url = self._client.service_instance._href_definitions.get_asset_href(script_uid) + "/revisions"
         # /v2/assets/{asset_id}/revisions returns 'results' object
         script_resources = self._get_with_or_without_limit(url,
                                                            limit,
@@ -1087,7 +1087,7 @@ class Script(WMLResource):
         if rev_uid is None:
             rev_uid = 'latest'
 
-        url = self._href_definitions.get_asset_href(script_uid)
+        url = self._client.service_instance._href_definitions.get_asset_href(script_uid)
         # return self._get_required_element_from_response(self._get_with_or_without_limit(url,
         #                                        limit=None,
         #                                        op_name="asset_revision",
@@ -1124,10 +1124,10 @@ class Script(WMLResource):
         Script._validate_type(asset_uid, u'asset_uid', STR_TYPE, True)
 
         if not self._ICP:
-            response = requests.delete(self._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                        headers=self._client._get_headers())
         else:
-            response = requests.delete(self._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
+            response = requests.delete(self._client.service_instance._href_definitions.get_asset_href(asset_uid), params=self._client._params(),
                                        headers=self._client._get_headers(), verify=False)
 
     def _get_required_element_from_response(self, response_data):
@@ -1168,7 +1168,7 @@ class Script(WMLResource):
             elif self._client.default_project_id is not None:
                 if self._client.WSD:
 
-                    href = "/v2/assets/" + response_data['metadata']['asset_id'] + "?" + "project_id=" + response_data['metadata']['project_id']
+                    href = self._client.service_instance._href_definitions.get_base_asset_href(response_data['metadata']['asset_id']) + "?" + "project_id=" + response_data['metadata']['project_id']
 
                     metadata = {'project_id': response_data['metadata']['project_id'],
                                 'guid': response_data['metadata']['asset_id'],
