@@ -188,7 +188,7 @@ class Spaces(WMLResource):
         space_uid = str_type_conv(space_uid)
         Spaces._validate_type(space_uid, u'space_uid', STR_TYPE, True)
 
-        space_endpoint = self._href_definitions.get_space_href(space_uid)
+        space_endpoint = self._client.service_instance._href_definitions.get_space_href(space_uid)
         if not self._ICP:
             response_delete = requests.delete(space_endpoint, headers=self._client._get_headers())
         else:
@@ -229,7 +229,7 @@ class Spaces(WMLResource):
         Spaces._validate_type(space_uid, u'space_uid', STR_TYPE, False)
         Spaces._validate_type(limit, u'limit', int, False)
 
-        href = self._href_definitions.get_spaces_href()
+        href = self._client.service_instance._href_definitions.get_spaces_href()
         if space_uid is None:
             return self._get_no_space_artifact_details(href+"?include=name,tags,custom,description", None, limit, 'spaces')
         return self._get_no_space_artifact_details(href, space_uid, limit, 'spaces')
@@ -297,7 +297,7 @@ class Spaces(WMLResource):
         patch_payload = self.ConfigurationMetaNames._generate_patch_payload(details['entity'], changes,
                                                                             with_validation=True)
 
-        href = self._href_definitions.get_space_href(space_uid)
+        href = self._client.service_instance._href_definitions.get_space_href(space_uid)
         if not self._ICP:
             response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
         else:
@@ -346,7 +346,7 @@ class Spaces(WMLResource):
 
         Spaces._validate_type(limit, u'limit', int, False)
 
-        href = self._href_definitions.get_members_href(space_uid)
+        href = self._client.service_instance._href_definitions.get_members_href(space_uid)
 
         return self._get_no_space_artifact_details(href, member_uid, limit, 'space members')
 
@@ -382,7 +382,7 @@ class Spaces(WMLResource):
         member_id = str_type_conv(member_id)
         Spaces._validate_type(member_id, u'member_id', STR_TYPE, True)
 
-        member_endpoint = self._href_definitions.get_member_href(space_uid,member_id)
+        member_endpoint = self._client.service_instance._href_definitions.get_member_href(space_uid,member_id)
         if not self._ICP:
             response_delete = requests.delete(member_endpoint, headers=self._client._get_headers())
         else:
@@ -434,7 +434,7 @@ class Spaces(WMLResource):
             patch_payload = self.MemberMetaNames._generate_patch_payload(details['entity'], changes,
                                                                                 with_validation=True)
 
-            href = self._href_definitions.get_member_href(space_uid,member_id)
+            href = self._client.service_instance._href_definitions.get_member_href(space_uid,member_id)
             if not self._ICP:
                 response = requests.patch(href, json=patch_payload, headers=self._client._get_headers())
             else:
@@ -632,7 +632,7 @@ class Spaces(WMLResource):
         with open(str(file_path), 'rb') as archive:
             data = archive.read()
 
-        href = self._href_definitions.get_space_href(space_uid) + "/imports"
+        href = self._client.service_instance._href_definitions.get_space_href(space_uid) + "/imports"
 
 
         if not self._ICP:
@@ -738,9 +738,9 @@ class Spaces(WMLResource):
 
 
         if imports_id is None:
-            href = self._href_definitions.get_space_href(space_uid) + "/imports"
+            href = self._client.service_instance._href_definitions.get_space_href(space_uid) + "/imports"
         else:
-            href =  self._href_definitions.get_space_href(space_uid) + "/imports/" + imports_id
+            href =  self._client.service_instance._href_definitions.get_space_href(space_uid) + "/imports/" + imports_id
 
         if not self._ICP:
             response = requests.get(href, headers=self._client._get_headers())
@@ -791,7 +791,7 @@ class Spaces(WMLResource):
         space_uid = str_type_conv(space_uid)
         self._validate_type(space_uid, u'space_uid', STR_TYPE, True)
 
-        href = self._href_definitions.get_space_href(space_uid) + "/exports"
+        href = self._client.service_instance._href_definitions.get_space_href(space_uid) + "/exports"
 
         if not self._ICP:
             response = requests.post(href, headers=self._client._get_headers(), data=space_exports_meta_json)
@@ -838,9 +838,9 @@ class Spaces(WMLResource):
 
 
         if exports_id is None:
-            href = self._href_definitions.get_space_href(space_uid) + "/exports"
+            href = self._client.service_instance._href_definitions.get_space_href(space_uid) + "/exports"
         else:
-            href =  self._href_definitions.get_space_href(space_uid) + "/exports/" + exports_id
+            href =  self._client.service_instance._href_definitions.get_space_href(space_uid) + "/exports/" + exports_id
 
         if not self._ICP:
             response = requests.get(href, headers=self._client._get_headers())
@@ -883,7 +883,7 @@ class Spaces(WMLResource):
         if space_exports_uid is not None and not is_uid(space_exports_uid):
             raise WMLClientError(u'\'space_exports_uid\' is not an uid: \'{}\''.format(space_exports_uid))
 
-        href =  self._href_definitions.get_space_href(space_uid) + "/exports/" + space_exports_uid + "/content"
+        href =  self._client.service_instance._href_definitions.get_space_href(space_uid) + "/exports/" + space_exports_uid + "/content"
 
         if not self._ICP:
             response = requests.get(
