@@ -18,16 +18,12 @@ from ibm_watson_machine_learning.experiment.autoai.optimizers import RemoteAutoP
 from ibm_watson_machine_learning.utils.autoai.errors import NotExistingCOSResource
 
 from ibm_watson_machine_learning.tests.utils import (get_wml_credentials, get_cos_credentials, bucket_exists,
-                                                        bucket_name_gen, get_space_id, is_cp4d)
-from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup, space_cleanup, delete_model_deployment
+                                                        create_bucket, get_space_id, is_cp4d)
+from ibm_watson_machine_learning.tests.utils.cleanup import space_cleanup, delete_model_deployment
 
 from ibm_watson_machine_learning.utils.autoai.enums import PositiveLabelClass, TShirtSize, Transformers
 
 
-from lale import wrap_imported_operators
-from lale.operators import TrainablePipeline
-from lale.lib.lale import Hyperopt
-
 
 class TestAutoAIRemote(unittest.TestCase):
     """
@@ -97,6 +93,14 @@ class TestAutoAIRemote(unittest.TestCase):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
 
         if not cls.wml_client.ICP:
@@ -119,7 +123,6 @@ class TestAutoAIRemote(unittest.TestCase):
         else:
             self.wml_client.set.default_space(self.space_id)
 
-
     def test_00b_prepare_COS_instance(self):
         if self.wml_client.ICP:
             self.skipTest("Prepare COS is available only for Cloud")
@@ -132,15 +135,7 @@ class TestAutoAIRemote(unittest.TestCase):
         )
         # Prepare bucket
         if not bucket_exists(cos_resource, self.bucket_name):
-            try:
-                bucket_cleanup(cos_resource, prefix=f"{self.bucket_name}-")
-            except Exception as e:
-                print(f"Bucket cleanup with prefix {self.bucket_name}- failed due to:\n{e}\n skipped")
-
-            import datetime
-            TestAutoAIRemote.bucket_name = bucket_name_gen(prefix=f"{self.bucket_name}-{str(datetime.date.today())}")
-            print(f"Creating COS bucket: {TestAutoAIRemote.bucket_name}")
-            cos_resource.Bucket(TestAutoAIRemote.bucket_name).create()
+            TestAutoAIRemote.bucket_name = create_bucket(cos_resource, self.bucket_name)
 
             self.assertIsNotNone(TestAutoAIRemote.bucket_name)
             self.assertTrue(bucket_exists(cos_resource, TestAutoAIRemote.bucket_name))
@@ -193,8 +188,8 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_column=self.prediction_column,
             positive_label=self.positive_label,
             scoring=PositiveLabelClass.PRECISION_SCORE_MICRO,
-            cognito_transform_names=[Transformers.DIFF,Transformers.SUM,Transformers.MAX,
-                                     Transformers.SIN,Transformers.SUM],
+            include_only_estimators=[self.experiment.ClassificationAlgorithms.XGB,
+                                     self.experiment.ClassificationAlgorithms.LGBM],
             test_size=0.1,
             max_number_of_estimators=1,
             t_shirt_size=TShirtSize.S if self.wml_client.ICP else TShirtSize.L
@@ -218,6 +213,8 @@ class TestAutoAIRemote(unittest.TestCase):
 
         self.assertIsNotNone(self.data_connection.auto_pipeline_params,
                              msg='DataConnection auto_pipeline_params was not updated.')
+        # TestAutoAIRemote.run_id = '2360fdc3-f06d-4053-9485-23ee9736f8e4'
+        # TestAutoAIRemote.remote_auto_pipelines = self.experiment.runs.get_optimizer(TestAutoAIRemote.run_id)
 
     def test_05a_fit_error_when_cos_file_not_exists(self):
         if self.wml_client.ICP:
@@ -266,7 +263,7 @@ class TestAutoAIRemote(unittest.TestCase):
 
     def test_08_get_run_details(self):
         parameters = self.remote_auto_pipelines.get_run_details()
-        # print(parameters)
+        print(parameters)
         self.assertIsNotNone(parameters)
 
     def test_09_predict_using_fitted_pipeline(self):
@@ -300,8 +297,8 @@ class TestAutoAIRemote(unittest.TestCase):
         TestAutoAIRemote.pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name='Pipeline_4')
         print(f"Fetched pipeline type: {type(self.pipeline)}")
 
-        self.assertIsInstance(self.pipeline, TrainablePipeline,
-                              msg="Fetched pipeline is not of TrainablePipeline instance.")
+        # self.assertIsInstance(self.pipeline, TrainablePipeline,
+        #                       msg="Fetched pipeline is not of TrainablePipeline instance.")
         predictions = self.pipeline.predict(
             X=self.X_values[:5])  # works with autoai_libs from branch `development` (date: 9th March 20)
         print(predictions)
@@ -315,7 +312,7 @@ class TestAutoAIRemote(unittest.TestCase):
             lale_pipeline = None
             try:
                 lale_pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name=pipeline_name)
-                self.assertIsInstance(lale_pipeline, TrainablePipeline)
+                # self.assertIsInstance(lale_pipeline, TrainablePipeline)
                 predictions = lale_pipeline.predict(
                     X=self.X_values[:1])
                 print(predictions)
