@@ -1,7 +1,7 @@
 import unittest
 from sklearn.pipeline import Pipeline
-from lale.operators import TrainablePipeline
-from lale.lib.lale import Hyperopt
+# from lale.operators import TrainablePipeline
+# from lale.lib.lale import Hyperopt
 import traceback
 
 from ibm_watson_machine_learning import APIClient
@@ -76,6 +76,14 @@ class TestAutoAIRemote(unittest.TestCase):
         """
 
         cls.wml_credentials = get_wml_credentials()
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
         cls.project_id = cls.wml_credentials.get('project_id')
         cls.connection_id, cls.data_location, _ = setup_nfs_env(cls.wml_credentials, cls.dataset_name)
@@ -112,7 +120,7 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_type=self.experiment.PredictionType.MULTICLASS,
             prediction_column='species',
             scoring=self.experiment.Metrics.ACCURACY_SCORE,
-            test_size=0.15,
+            holdout_size=0.15,
             max_number_of_estimators=1,
             csv_separator=self.custom_separator,
             t_shirt_size=TShirtSize.S
@@ -202,6 +210,7 @@ class TestAutoAIRemote(unittest.TestCase):
         TestAutoAIRemote.lale_pipeline = self.remote_auto_pipelines.get_pipeline(
             pipeline_name='Pipeline_1')
         print(f"Fetched pipeline type: {type(self.lale_pipeline)}")
+        from lale.operators import TrainablePipeline
         self.assertIsInstance(self.lale_pipeline, TrainablePipeline)
 
     def test_14_get_all_pipelines_as_lale(self):
@@ -213,6 +222,7 @@ class TestAutoAIRemote(unittest.TestCase):
             lale_pipeline = None
             try:
                 lale_pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name=pipeline_name)
+                from lale.operators import TrainablePipeline
                 self.assertIsInstance(lale_pipeline, TrainablePipeline)
                 predictions = lale_pipeline.predict(
                     X=self.train_data.values[:1])
@@ -240,13 +250,16 @@ class TestAutoAIRemote(unittest.TestCase):
                               msg=f"Pretty print from lale pipeline was not successful \n\n Full pipeline code:\n {pipeline_code}")
 
     def test_14c_remove_last_freeze_trainable_prefix_returned(self):
+        from lale.operators import TrainablePipeline
         from lale.lib.sklearn import KNeighborsClassifier, DecisionTreeClassifier, LogisticRegression
+
         prefix = self.lale_pipeline.remove_last().freeze_trainable()
         self.assertIsInstance(prefix, TrainablePipeline,
                               msg="Prefix pipeline is not of TrainablePipeline instance.")
         TestAutoAIRemote.new_pipeline = prefix >> (KNeighborsClassifier| DecisionTreeClassifier| LogisticRegression)
 
     def test_14d_hyperopt_fit_new_pipepiline(self):
+        from lale.lib.lale import Hyperopt
 
         X_values = self.train_data.drop(['species'], axis=1).values
         y_values = self.train_data['species'].values
