@@ -75,6 +75,14 @@ class TestAutoAIRemote(unittest.TestCase):
         """
 
         cls.wml_credentials = get_wml_credentials()
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         cls.wml_client = APIClient(wml_credentials=cls.wml_credentials.copy())
         cls.project_id = cls.wml_credentials.get('project_id')
         cls.connection_id, cls.data_location, _ = setup_nfs_env(cls.wml_credentials, cls.dataset_name)
@@ -114,7 +122,7 @@ class TestAutoAIRemote(unittest.TestCase):
             prediction_type=self.experiment.PredictionType.MULTICLASS,
             prediction_column='species',
             scoring=self.experiment.Metrics.ACCURACY_SCORE,
-            test_size=0.15,
+            holdout_size=0.15,
             max_number_of_estimators=1,
             csv_separator=self.custom_separator,
             t_shirt_size=TShirtSize.S
