@@ -20,17 +20,14 @@ from ibm_watson_machine_learning.tests.utils import print_test_separators
 from ibm_watson_machine_learning.utils.autoai.errors import WrongDataJoinGraphNodeName, OBMMainNodeAlreadySet
 
 from ibm_watson_machine_learning.tests.utils import get_wml_credentials, get_cos_credentials, is_cp4d, bucket_exists, \
-    bucket_name_gen, get_space_id
+    create_bucket, get_space_id
 
-from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment, bucket_cleanup, space_cleanup
+from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment, space_cleanup
 
 
 
 from ibm_watson_machine_learning.tests.utils.cleanup import delete_model_deployment
 
-from lale import wrap_imported_operators
-from lale.operators import TrainablePipeline
-from lale.lib.lale import Hyperopt
 
 get_step_details = OBMPipelineGraphBuilder.get_step_details
 get_join_extractors = OBMPipelineGraphBuilder.get_join_extractors
@@ -118,6 +115,14 @@ class TestOBMAndKB(unittest.TestCase):
         Load WML credentials from config.ini file based on ENV variable.
         """
         cls.wml_credentials = get_wml_credentials()
+        try:
+            del cls.wml_credentials['bedrock_url']
+        except:
+            pass
+        try:
+            del cls.wml_credentials['password']
+        except:
+            pass
         if not is_cp4d():
             cls.cos_credentials = get_cos_credentials()
             cls.cos_endpoint = cls.cos_credentials.get('endpoint_url')
@@ -154,15 +159,7 @@ class TestOBMAndKB(unittest.TestCase):
         )
         # Prepare bucket
         if not bucket_exists(cos_resource, self.bucket_name):
-            try:
-                bucket_cleanup(cos_resource, prefix=f"{self.bucket_name}-")
-            except Exception as e:
-                print(f"Bucket cleanup with prefix {self.bucket_name}- failed due to:\n{e}\n skipped")
-
-            import datetime
-            TestOBMAndKB.bucket_name = bucket_name_gen(prefix=f"{self.bucket_name}-{str(datetime.date.today())}")
-            print(f"Creating COS bucket: {TestOBMAndKB.bucket_name}")
-            cos_resource.Bucket(TestOBMAndKB.bucket_name).create()
+            TestOBMAndKB.bucket_name = create_bucket(cos_resource, self.bucket_name)
 
             self.assertIsNotNone(TestOBMAndKB.bucket_name)
             self.assertTrue(bucket_exists(cos_resource, TestOBMAndKB.bucket_name))
@@ -309,7 +306,7 @@ class TestOBMAndKB(unittest.TestCase):
             max_number_of_estimators=1,
             data_join_graph=self.data_join_graph,
             t_shirt_size=self.experiment.TShirtSize.L,
-            test_size=0.1,
+            holdout_size=0.1,
             autoai_pod_version=self.pod_version
         )
 
@@ -536,8 +533,8 @@ class TestOBMAndKB(unittest.TestCase):
                               msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
         print(f"Fetched pipeline type: {type(self.lale_pipeline)}")
 
-        self.assertIsInstance(self.lale_pipeline, TrainablePipeline,
-                              msg="Fetched pipeline is not of TrainablePipeline instance.")
+        # self.assertIsInstance(self.lale_pipeline, TrainablePipeline,
+        #                       msg="Fetched pipeline is not of TrainablePipeline instance.")
 
     @print_test_separators
     def test_19b_get_all_pipelines_as_lale(self):
@@ -552,6 +549,7 @@ class TestOBMAndKB(unittest.TestCase):
                 lale_pipeline = self.remote_auto_pipelines.get_pipeline(pipeline_name=pipeline_name)
                 self.assertWarnsRegex(Warning, "OBM",
                                       msg="Warning (OBM pipeline support only for inspection and deployment) was not raised")
+                from lale.operators import TrainablePipeline
                 self.assertIsInstance(lale_pipeline, TrainablePipeline)
                 predictions = lale_pipeline.predict(X=self.train_data.drop([self.prediction_column], axis=1).values[:1])
                 print(predictions)
@@ -583,12 +581,14 @@ class TestOBMAndKB(unittest.TestCase):
         print("Prepare pipeline to refinery...")
         from lale.lib.sklearn import KNeighborsClassifier, DecisionTreeClassifier, LogisticRegression
         prefix = self.lale_pipeline.remove_last().freeze_trainable()
-        self.assertIsInstance(prefix, TrainablePipeline,
-                              msg="Prefix pipeline is not of TrainablePipeline instance.")
+        # self.assertIsInstance(prefix, TrainablePipeline,
+        #                       msg="Prefix pipeline is not of TrainablePipeline instance.")
         TestOBMAndKB.new_pipeline = prefix >> (KNeighborsClassifier | DecisionTreeClassifier | LogisticRegression)
 
     @print_test_separators
     def test_20b_hyperopt_fit_new_pipepiline(self):
+        from lale.lib.lale import Hyperopt
+
         print("Do a hyperparameters optimization...")
         hyperopt = Hyperopt(estimator=TestOBMAndKB.new_pipeline, cv=3, max_evals=2)
         try:
@@ -738,7 +738,7 @@ class TestOBMAndKB(unittest.TestCase):
             ),
             prediction_type=self.experiment.PredictionType.BINARY,
             prediction_column=self.prediction_column,
-            test_size=0.1,
+            holdout_size=0.1,
             scoring=self.experiment.Metrics.ACCURACY_SCORE,
             max_number_of_estimators=1,
         )
