@@ -1,9 +1,13 @@
 import json
 import os
 import time
+import datetime
 from configparser import ConfigParser
 from functools import wraps
-from  time import sleep
+from time import sleep
+
+from ibm_watson_machine_learning.tests.utils.cleanup import bucket_cleanup
+
 __all__ = [
     "get_wml_credentials",
     "get_cos_credentials",
@@ -11,6 +15,7 @@ __all__ = [
     "is_cp4d",
     "bucket_exists",
     "bucket_name_gen",
+    "create_bucket",
     'print_test_separators',
     "get_space_id",
     "resources_discovery",
@@ -78,6 +83,22 @@ def bucket_name_gen(prefix='bucket-tests', id_size=8):
     return prefix + "-" + ''.join(random.choice(string.ascii_lowercase + string.digits) for x in range(id_size))
 
 
+def create_bucket(cos_resource, bucket_name):
+    """
+    Creates bucket of with a given name and timestamp suffix.
+    """
+    try:
+        bucket_cleanup(cos_resource, prefix=f"{bucket_name}-")
+    except Exception as e:
+        print(f"Bucket cleanup with prefix {bucket_name}- failed due to:\n{e}\n skipped")
+
+    bucket_name = bucket_name_gen(prefix=f"{bucket_name}-{str(datetime.date.today())}")
+    print(f"Creating COS bucket: {bucket_name}")
+    cos_resource.Bucket(bucket_name).create()
+
+    return bucket_name
+
+
 def print_test_separators(method):
     """Printing visual separators for tests."""
     @wraps(method)
