@@ -101,7 +101,7 @@ def fetch_pipelines(run_params: dict,
                     wml_client: 'APIClient',
                     pipeline_name: str = None,
                     load_pipelines: bool = False,
-                    store: bool = False) -> Union[None, Dict[str, 'Pipeline']]:
+                    store: bool = False) -> Tuple[Union[None, Dict[str, 'Pipeline']], bool]:
     """
     Helper function to download and load computed AutoAI pipelines (sklearn pipelines).
 
@@ -129,7 +129,7 @@ def fetch_pipelines(run_params: dict,
     List of sklearn Pipelines or None if load_pipelines is set to False.
     """
 
-    def check_pipeline_nodes(pipeline: dict, request_json: dict, wml_client) -> None:
+    def check_pipeline_nodes(pipeline: dict, request_json: dict, wml_client) -> bool:
         """
         Automate check all pipeline nodes to find xgboost or lightgbm dependency.
         """
@@ -139,22 +139,25 @@ def fetch_pipelines(run_params: dict,
         # note: check dependencies for estimators and other packages
         estimator_name = pipeline['context']['intermediate_model'].get('pipeline_nodes', [None])[-1]
         if estimator_name in xgboost_estimators:
-            check_dependencies_versions(request_json, wml_client, 'xgboost')
+            check_lale = check_dependencies_versions(request_json, wml_client, 'xgboost')
 
         elif estimator_name in lightgbm_estimators:
-            check_dependencies_versions(request_json, wml_client, 'lightgbm')
+            check_lale = check_dependencies_versions(request_json, wml_client, 'lightgbm')
 
         else:
-            check_dependencies_versions(request_json, wml_client, None)
+            check_lale = check_dependencies_versions(request_json, wml_client, None)
 
         # TODO: When another package estimators will be available update above!
         # --- end note
 
+        return check_lale
+
     joblib = try_import_joblib()
 
     path = os.path.abspath(path)
     pipelines_names = []
     pipelines = {}
+    check_lale = True
 
     if wml_client.ICP:
         model_paths = []
@@ -174,7 +177,8 @@ def fetch_pipelines(run_params: dict,
 
                 # note: check dependencies for estimators
                 request_json = download_request_json(run_params, pipelines_names[-1], wml_client)
-                check_pipeline_nodes(pipeline, request_json, wml_client)
+                check_lale = check_pipeline_nodes(pipeline, request_json, wml_client)
+
 
             # checking only chosen pipeline
             elif pipeline_name == f"Pipeline_{pipeline['context']['intermediate_model']['name'].split('P')[-1]}":
@@ -183,7 +187,7 @@ def fetch_pipelines(run_params: dict,
 
                 # note: check dependencies for estimators and other packages
                 request_json = download_request_json(run_params, pipelines_names[-1], wml_client)
-                check_pipeline_nodes(pipeline, request_json, wml_client)
+                check_lale = check_pipeline_nodes(pipeline, request_json, wml_client)
 
                 break
             # --- end note
@@ -208,7 +212,7 @@ def fetch_pipelines(run_params: dict,
     else:
         from ibm_boto3 import client
         cos_client = client(
-            service_name=run_params['entity']['results_reference']['type'],
+            service_name='s3',
             endpoint_url=run_params['entity']['results_reference']['connection']['endpoint_url'],
             aws_access_key_id=run_params['entity']['results_reference']['connection']['access_key_id'],
             aws_secret_access_key=run_params['entity']['results_reference']['connection']['secret_access_key']
@@ -234,7 +238,7 @@ def fetch_pipelines(run_params: dict,
 
                     # note: check dependencies for estimators and other packages
                     request_json = download_request_json(run_params, pipelines_names[-1], wml_client)
-                    check_pipeline_nodes(pipeline, request_json, wml_client)
+                    check_lale = check_pipeline_nodes(pipeline, request_json, wml_client)
 
                 elif pipeline_name == f"Pipeline_{pipeline['context']['intermediate_model']['name'].split('P')[-1]}":
                     buckets = [run_params['entity']['results_reference']['location']['bucket']]
@@ -245,7 +249,7 @@ def fetch_pipelines(run_params: dict,
 
                     # note: check dependencies for estimators and other packages
                     request_json = download_request_json(run_params, pipelines_names[-1], wml_client)
-                    check_pipeline_nodes(pipeline, request_json, wml_client)
+                    check_lale = check_pipeline_nodes(pipeline, request_json, wml_client)
 
                     break
 
@@ -269,7 +273,7 @@ def fetch_pipelines(run_params: dict,
                     # --- end note
 
     if load_pipelines and pipelines:
-        return pipelines
+        return pipelines, check_lale
 
     elif load_pipelines:
         raise MissingPipeline(
@@ -310,7 +314,7 @@ def load_file_from_file_system(wml_client: 'APIClient',
 
     buffer = io.BytesIO()
     response_with_model = requests.get(
-        url=f"{wml_client.data_assets._href_definitions.get_wsd_model_attachment_href()}auto_ml/{file_path}",
+        url=f"{wml_client.service_instance._href_definitions.get_wsd_model_attachment_href()}auto_ml/{file_path}",
         headers=wml_client._get_headers(),
         stream=stream,
         verify=False)
@@ -358,7 +362,7 @@ def load_file_from_file_system_nonautoai(wml_client: 'APIClient',
     buffer = io.BytesIO()
 
     response_with_model = requests.get(
-        url=f"{wml_client.data_assets._href_definitions.get_wsd_model_attachment_href()}{file_path}",
+        url=f"{wml_client.service_instance._href_definitions.get_wsd_model_attachment_href()}{file_path}",
         headers=wml_client._get_headers(),
         stream=stream,
         verify=False)
@@ -413,7 +417,6 @@ def preprocess_request_json(request_json: Dict, space_id: str) -> Dict:
 
     request_json['space_id'] = space_id
     request_json.pop('pipeline')  # not needed for other space
-    request_json.pop('training_data_references')  # not needed for other space
     # --- end note
     return request_json
 
@@ -494,7 +497,8 @@ def prepare_auto_ai_model_to_publish_notebook_normal_scenario(
             request_str = f.read()
 
     request_json: Dict[str, dict] = json.loads(request_str)
-    request_json['content_location']['connection'] = run_params['entity']['results_reference']['connection']
+    if 'connection' in run_params['entity']['results_reference']:
+        request_json['content_location']['connection'] = run_params['entity']['results_reference']['connection']
     request_json = preprocess_request_json(request_json, space_id)
     artifact_name = f"autoai_sdk{os.path.sep}{pipeline_model}.pickle"
 
@@ -622,7 +626,8 @@ def prepare_auto_ai_model_to_publish_normal_scenario(
     """
     request_json: Dict[str, dict] = download_request_json(run_params, pipeline_model, wml_client)
     # note: fill connection details
-    request_json['content_location']['connection'] = run_params['entity']['results_reference']['connection']
+    if 'connection' in run_params['entity']['results_reference']:
+        request_json['content_location']['connection'] = run_params['entity']['results_reference']['connection']
     # note: if training was on project_id, change it to space_id as we can deploy only on space
     request_json = preprocess_request_json(request_json, space_id)
     artifact_name = f"autoai_sdk{os.path.sep}{pipeline_model}.pickle"
@@ -848,12 +853,16 @@ def try_import_lale():
     """
     Check if lale package is installed in local environment, if not, just download and install it.
     """
-    lale_version = '0.4.14'
+    lale_version = '0.4.15'
     try:
-        import lale
-        from packaging import version
-        if version.parse(lale.__version__) < version.parse(lale_version):
-            warn(f"\"lale\" package version is to low."
+        try:
+            installed_module_version = fallback_to_pip_for_version_check({'name': 'lale'})
+
+        except Exception:
+            installed_module_version = pkg_resources.get_distribution('lale').version
+
+        if version.parse(installed_module_version) < version.parse(lale_version):
+            warn(f"\"lale\" package version is too low than {lale_version}."
                  f"Installing version {lale_version}")
 
             try:
@@ -863,8 +872,8 @@ def try_import_lale():
                 raise CannotInstallLibrary(value_name=e,
                                            reason="lale failed to install. Please install it manually.")
 
-    except AttributeError:
-        warn(f"Cannot determine \"lale\" package version."
+    except pkg_resources.DistributionNotFound as e:
+        warn(f"\"lale\" is not installed."
              f"Installing version {lale_version}")
 
         try:
@@ -874,17 +883,6 @@ def try_import_lale():
             raise CannotInstallLibrary(value_name=e,
                                        reason="lale failed to install. Please install it manually.")
 
-    except ImportError:
-        warn(f"\"lale\" package is not installed. "
-             f"This is the needed dependency for pipeline model refinery, we will try to install it now...")
-
-        try:
-            check_call([executable, "-m", "pip", "install", f"lale=={lale_version}"])
-
-        except Exception as e:
-            raise CannotInstallLibrary(value_name=e,
-                                       reason="lale failed to install. Please install it manually.")
-
 
 def try_import_autoai_libs():
     """
@@ -1022,7 +1020,7 @@ def try_load_dataset(
     return data
 
 
-def check_dependencies_versions(request_json: dict, wml_client, estimator_pkg: str) -> None:
+def check_dependencies_versions(request_json: dict, wml_client, estimator_pkg: str) -> bool:
     """
     Check packages installed versions and inform the user about needed ones.
 
@@ -1042,6 +1040,11 @@ def check_dependencies_versions(request_json: dict, wml_client, estimator_pkg: s
     sw_spec = wml_client.software_specifications.get_details(sw_spec_id)
 
     packages = sw_spec['entity']['software_specification']['software_configuration']['included_packages']
+
+    check_lale = True
+    if 'lale' in str(packages):
+        check_lale = False
+
     packages_to_check = ['numpy', 'scikit-learn', 'autoai-libs', 'gensim', 'lale']
 
     if estimator_pkg is not None:
@@ -1053,10 +1056,15 @@ def check_dependencies_versions(request_json: dict, wml_client, estimator_pkg: s
     for package in packages:
         if package['name'] in packages_to_check:
             try:
-                installed_module_version = pkg_resources.get_distribution(package['name']).version
+                # note: try to use pip for version check! if failed use pkg_resources
+                try:
+                    installed_module_version = fallback_to_pip_for_version_check(package)
+
+                except Exception:
+                    installed_module_version = pkg_resources.get_distribution(package['name']).version
 
                 # workaround for autai-libs and numpy versions in SW spec
-                if package['name'] == 'autoai-libs' or package['name'] == 'numpy':
+                if package['name'] == 'autoai-libs' or package['name'] == 'numpy' or package['name'] == 'lale':
                     if version.parse(installed_module_version) < version.parse(package['version']):
                         errored_packages.append(package)
 
@@ -1076,6 +1084,8 @@ def check_dependencies_versions(request_json: dict, wml_client, estimator_pkg: s
                                           f"These packages are required to load ML model successfully "
                                           f"on your environment.")
 
+    return check_lale
+
 
 def prepare_cos_client(
         training_data_references: List['DataConnection'] = None,
@@ -1124,13 +1134,14 @@ def prepare_cos_client(
     data_cos_clients = []
 
     if training_result_reference is not None:
-        if isinstance(training_result_reference.connection, S3Connection):
+        if (isinstance(training_result_reference.connection, S3Connection) or
+                training_result_reference._check_if_connection_asset_is_s3()):
             cos_client_results = (training_result_reference,
                                   differentiate_between_credentials(connection=training_result_reference.connection))
 
     if training_data_references is not None:
         for reference in training_data_references:
-            if isinstance(reference.connection, S3Connection):
+            if isinstance(reference.connection, S3Connection) or reference._check_if_connection_asset_is_s3():
                 data_cos_clients.append((reference,
                                          differentiate_between_credentials(connection=reference.connection)))
 
@@ -1453,7 +1464,9 @@ def validate_additional_params_for_optimizer(params):
         'FE_drop_constant_columns_flag', 'FE_add_frequency_columns_flag', 'FE_add_missing_indicator_columns_flag',
         'data_provenance', 'target_label_name', 'preprocessor_data_filename', 'cognito_data_filename',
         'holdout_roc_curve_max_size', 'holdout_reg_pred_obs_max_size', 'max_estimator_n_jobs',
-        'enabled_feature_engineering_as_json', 'fairness_info', 'text_processing', 'word2vec_feature_number']
+        'enabled_feature_engineering_as_json', 'fairness_info', 'text_processing', 'word2vec_feature_number',
+        '_enable_snapml_estimators'
+    ]
 
     for k in params:
         if k not in expected_params:
@@ -1534,7 +1547,8 @@ def is_list_composed_from_enum(sequence: List[Union[str, enum.Enum]],
         for el in sequence:
             el_value = el.value if isinstance(el, enum.Enum) else el
             if el_value not in enum_values:
-                raise InvalidSequenceValue(el, enum_values)
+                if f"{el_value}Estimator" not in enum_values:
+                    raise InvalidSequenceValue(el, enum_values)
 
 
 def validate_optimizer_enum_values(
@@ -1587,3 +1601,24 @@ def validate_optimizer_enum_values(
     # Note: scoring can be None or have one of values from Metrics enum.
     if scoring is not None:
         is_list_composed_from_enum([scoring], Metrics)
+
+
+def fallback_to_pip_for_version_check(package: dict) -> str:
+    """Use only when you need to check package version by package name with pip."""
+    try:
+        from pip._internal.utils.misc import get_installed_distributions
+        packages = get_installed_distributions()
+        installed_module_version = None
+        for pkg in packages:
+            if pkg.key == package['name']:
+                installed_module_version = pkg._version
+                break
+
+        if installed_module_version is None:
+            raise pkg_resources.DistributionNotFound()
+
+        else:
+            return installed_module_version
+
+    except Exception:
+        raise pkg_resources.DistributionNotFound()
